_positive = set(
    [
        "abba",
        "evne",
        "NO TRANSLATION",
        "absolut",
        "syndsforladelse",
        "absorberet",
        "rigelig",
        "akademisk",
        "akademi",
        "acceptabel",
        "accept",
        "tilgængelig",
        "hyldest",
        "indkvartering",
        "akkompagnement",
        "opnå",
        "gennemført",
        "realisering",
        "overenskomst",
        "ansvarlighed",
        "ansvarlig",
        "akkrediteret",
        "NO TRANSLATION",
        "nøjagtig",
        "es",
        "opnå",
        "præstation",
        "anerkendelse",
        "erhverve",
        "erhverve",
        "akrobat",
        "handling",
        "faktiske",
        "skarphed",
        "købmandskab",
        "tilpasse",
        "tilpasningsdygtige",
        "adresser",
        "dygtig",
        "NO TRANSLATION",
        "supplement",
        "beundringsværdig",
        "admiral",
        "beundring",
        "beundre",
        "beundrer",
        "realitetsbehandling",
        "yndig",
        "tilbedelse",
        "tilbede",
        "rykke",
        "fremskreden",
        "fremgang",
        "fordel",
        "fordelagtige",
        "advent",
        "eventyr",
        "eventyrlystne",
        "tilrådeligt",
        "rådgive",
        "rådgiver",
        "fortalervirksomhed",
        "æstetisk",
        "æstetik",
        "flink",
        "kærlighed",
        "tilknyttet",
        "bekræfte",
        "bekræftelse",
        "bekræftende",
        "bekræftende",
        "overflod",
        "velhavende",
        "har råd til",
        "NO TRANSLATION",
        "adræt",
        "smidighed",
        "enig",
        "behagelig",
        "aftalt",
        "enige",
        "aftale",
        "landbrug",
        "foran",
        "hjælpe",
        "medvirken",
        "alabast",
        "årvågenhed",
        "NO TRANSLATION",
        "i live",
        "dæmpe",
        "troskab",
        "allegro",
        "lindre",
        "lindring",
        "allieret",
        "tilladelige",
        "lokke",
        "dragende",
        "allieret",
        "almægtig",
        "aloha",
        "forbavsende",
        "ambassadør",
        "ambition",
        "lindre",
        "Amen",
        "modtagelig",
        "ændre",
        "godt igen",
        "rekreative områder",
        "elskværdig",
        "venskabelig",
        "amnesti",
        "NO TRANSLATION",
        "underholde",
        "morede",
        "underholdning",
        "underholdende",
        "analytiker",
        "anker",
        "forankring",
        "Engel",
        "engleblid",
        "animere",
        "animeret",
        "antibiotika",
        "modgift",
        "svampedræbende",
        "antik",
        "antiseptisk",
        "selvsikkerhed",
        "undskyldende",
        "undskylde",
        "apologi",
        "apostel",
        "bifald",
        "påskønnelse",
        "billigelse",
        "godkendelse",
        "godkende",
        "godkendelse",
        "apt",
        "evne",
        "arkæologi",
        "glødende",
        "iver",
        "aristokrati",
        "aristokratisk",
        "rustning",
        "aroma",
        "vække",
        "matrix",
        "kunst",
        "artikulere",
        "artikulation",
        "håndværker",
        "NO TRANSLATION",
        "kunstnerisk",
        "overtag",
        "opstigning",
        "forhåbning",
        "stræbe",
        "aspirerende",
        "montage",
        "samstemmende udtalelse",
        "hævde",
        "aktiver",
        "hjælpe",
        "hjælp",
        "associeret",
        "dæmpe",
        "forsikring",
        "sikker",
        "NO TRANSLATION",
        "forbavselse",
        "astrolog",
        "astronaut",
        "astronom",
        "snu",
        "atlet",
        "atletisk",
        "atom",
        "sone",
        "soning",
        "vedhæftet fil",
        "opnåelige",
        "virkeliggørelsen",
        "ledsager",
        "opmærksomhed",
        "opmærksom",
        "bevidne",
        "advokat",
        "attraktion",
        "tiltrækningskraft",
        "forøge",
        "august",
        "tante",
        "aura",
        "lovende",
        "autentisk",
        "ægthed",
        "forfatter",
        "autoritativ",
        "myndighed",
        "bemyndigelse",
        "autoriseret",
        "avatar",
        "pris",
        "ay",
        "aye",
        "baby",
        "studentereksamen",
        "rygrad",
        "balance",
        "afbalanceret",
        "ballade",
        "ballet",
        "afstemning",
        "balsam",
        "banket",
        "dåb",
        "dåb",
        "skjald",
        "godt køb",
        "basketball",
        "bastion",
        "bad",
        "bjælke",
        "strålende",
        "forskønnelse",
        "smuk",
        "forskønne",
        "skønhed",
        "grundfjeld",
        "øl",
        "befitting",
        "befriend",
        "tro",
        "velgører",
        "gavnlig",
        "fordel",
        "velvilje",
        "godartet",
        "køje",
        "trolovet",
        "gavn",
        "drik",
        "bibelsk",
        "tosproget",
        "fødsel",
        "fødselsdag",
        "uden skyld",
        "velsigne",
        "velsignet",
        "velsignelse",
        "velsignelser",
        "lyksalighed",
        "salig",
        "ublodig",
        "flor",
        "blomst",
        "livvagt",
        "dristig",
        "dristighed",
        "styrke",
        "bonanza",
        "NO TRANSLATION",
        "bonus",
        "boglig",
        "boghandel",
        "velsignelse",
        "sprudlende",
        "dusør",
        "buket",
        "hjerner",
        "tapperhed",
        "morgenmad",
        "brude",
        "brud",
        "Brudgom",
        "brudepige",
        "lysne",
        "lysstyrke",
        "strålende",
        "brokade",
        "bror",
        "broderskab",
        "broderlig",
        "kammerat",
        "bygge",
        "bygning",
        "bulldog",
        "skudsikker",
        "bøje",
        "buss",
        "butler",
        "smøragtig",
        "trivelig",
        "summen",
        "førerhus",
        "skab",
        "cafe",
        "lommeregner",
        "kalv",
        "berolige",
        "kanariefugl",
        "oprigtig",
        "kandidat",
        "kandiserede",
        "kapitalist",
        "kaptajn",
        "fange",
        "fængslende",
        "karriere",
        "forsigtig",
        "omhyggeligt",
        "kærtegn",
        "vicevært",
        "carol",
        "kaskade",
        "kontanter",
        "kategorisk",
        "imødekomme",
        "afføringsmiddel",
        "katedral",
        "forsigtig",
        "forsigtigt",
        "fejret",
        "fejrer",
        "fest",
        "himmelsk",
        "centrum",
        "centurion",
        "cerebral",
        "ceremoni",
        "sikkerhed",
        "formand",
        "forkvinde",
        "champion",
        "chant",
        "oplader",
        "velgørende",
        "velgørenhed",
        "charme",
        "charmerende",
        "kyskhed",
        "raslen",
        "tjekliste",
        "opmuntre",
        "glad",
        "munterhed",
        "jublende",
        "NO TRANSLATION",
        "kemiker",
        "værdsætte",
        "kirsebær",
        "høvding",
        "barn",
        "barndom",
        "pippe",
        "mejsel",
        "ridderlighed",
        "chokolade",
        "valg",
        "kor",
        "kor",
        "kor",
        "valgt",
        "saftige",
        "krønike",
        "klukle",
        "kirke",
        "cider",
        "omskæring",
        "borger",
        "civil",
        "høflighed",
        "civilisation",
        "civiliseret",
        "clairvoyant",
        "klappe",
        "klarlægge",
        "klassisk",
        "klassisk",
        "klassikere",
        "klassificere",
        "ren",
        "rengøring",
        "renhed",
        "rent",
        "rense",
        "udrensning",
        "clearance",
        "klarhed",
        "kontorarbejde",
        "dygtig",
        "dygtighed",
        "klimaks",
        "nærhed",
        "lukning",
        "NO TRANSLATION",
        "klovn",
        "koalition",
        "kyst",
        "sameksistere",
        "overbevisende",
        "kognitive",
        "sammenhæng",
        "sammenhængende",
        "sammenhængende",
        "kollektivt",
        "oberst",
        "kolossal",
        "komfort",
        "kommandant",
        "kommanderende",
        "mindes",
        "mindehøjtidelighed",
        "erindringsmønter",
        "rose",
        "prisværdigt",
        "kommentator",
        "engageret",
        "commodore",
        "commonwealth",
        "kommunikere",
        "kommunikative",
        "fællesskab",
        "fællesskab",
        "forvandling",
        "pendler",
        "ledsager",
        "medfølelse",
        "medfølende",
        "kompatibilitet",
        "kompatibel",
        "overbevisende",
        "kompensere",
        "kompenserende",
        "kompetence",
        "kompetenceudvikling",
        "kompetent",
        "selvtilfredshed",
        "supplement",
        "komplementær",
        "fuldstændig",
        "fuldstændighed",
        "færdiggøre",
        "færdiggørelse",
        "overholdelse",
        "kompatibel",
        "NO TRANSLATION",
        "komponeret",
        "komponist",
        "fatning",
        "forstå",
        "omfattende",
        "kammerat",
        "koncentriske",
        "forlig",
        "afsluttende",
        "concord",
        "konkordans",
        "kondolence",
        "tolererer",
        "befordrende",
        "ledningsevne",
        "confederate",
        "tillid",
        "selvsikker",
        "bekræftet",
        "overensstemmelse",
        "sympatisk",
        "komplimenterende",
        "menighed",
        "overensstemmelsen",
        "feinschmecker",
        "samvittighed",
        "samvittighedsfuld",
        "bevidsthed",
        "indvielse",
        "bevarelse",
        "spare",
        "betydelige",
        "hensynsfuld",
        "konsistens",
        "konsol",
        "konsonant",
        "konstans",
        "konstant",
        "forfatningsmæssig",
        "konstruere",
        "djævleblændt",
        "kontakt",
        "overvejelse",
        "indhold",
        "Blive ved",
        "kontur",
        "bidrage",
        "bidragsyder",
        "bekvemmelighed",
        "praktisk",
        "kloster",
        "konvention",
        "fortrolig",
        "konversation",
        "konvertere",
        "overbevise",
        "fedt nok",
        "kølighed",
        "samarbejde",
        "samarbejder",
        "samarbejde",
        "samarbejdsvillig",
        "kerne",
        "kroning",
        "virksomhed",
        "legemlig",
        "korrigerende",
        "korrespondance",
        "bestyrke",
        "kosmopolitisk",
        "hyggelig",
        "råd",
        "råd",
        "rådgiver",
        "tælle",
        "grevinde",
        "mod",
        "modig",
        "høflig",
        "høflighed",
        "frieri",
        "bugt",
        "pagt",
        "vugge",
        "håndværk",
        "håndværker",
        "fløde",
        "skab",
        "kreativ",
        "tiltro",
        "legitimationsoplysninger",
        "troværdighed",
        "troværdig",
        "kredit",
        "NO TRANSLATION",
        "krediteret",
        "crescendo",
        "kritik",
        "kronen",
        "afgørende",
        "krystal",
        "kæle",
        "kulinarisk",
        "kulmination",
        "dyrke",
        "dyrkede",
        "dyrkning",
        "kultur",
        "helbredes",
        "nysgerrighed",
        "krølle",
        "pude",
        "kunde",
        "nuttet",
        "kuttere",
        "dame",
        "dans",
        "vovemod",
        "skat",
        "flot",
        "datter",
        "daggry",
        "del",
        "Kære",
        "debat",
        "anstændighed",
        "anstændig",
        "deklaratorisk",
        "dedikation",
        "forsvare",
        "forsvarede",
        "forsvarer",
        "forsvare",
        "forsvar",
        "respekt",
        "endelige",
        "grad",
        "liflig",
        "delegeret",
        "bevidst",
        "lækker",
        "glæde",
        "glad",
        "dejlig",
        "udfrielse",
        "levering",
        "demokrati",
        "påviselige",
        "demonstrativ",
        "dybde",
        "beskrivende",
        "fortjener",
        "fortjente",
        "designer",
        "ønskelig",
        "ønsker",
        "som ønsker",
        "bestemmelsessted",
        "opdage",
        "opdagelse",
        "beslutsomhed",
        "fast besluttet",
        "udvikle",
        "andægtig",
        "fromme",
        "fingerfærdighed",
        "diamant",
        "dagbog",
        "ordbog",
        "didaktisk",
        "kosten",
        "værdig",
        "værdighed",
        "diligence",
        "aftensmad",
        "diplomati",
        "diplomatisk",
        "direktør",
        "opdagelse",
        "NO TRANSLATION",
        "skøn",
        "skønsmæssig",
        "diskussion",
        "desinfektion",
        "anbragt",
        "udbrede",
        "destillation",
        "forskel",
        "Vise",
        "diversificeret",
        "afledning",
        "guddommelighed",
        "læge",
        "handlingsmenneske",
        "udholdende",
        "delfin",
        "don",
        "donation",
        "uden tvivl",
        "due",
        "dunet",
        "duet",
        "duke",
        "holdbarhed",
        "holdbar",
        "pligtopfyldende",
        "ivrige",
        "Iver",
        "earl",
        "tjene",
        "alvor",
        "inderligt",
        "alvor",
        "lethed",
        "servitut",
        "NO TRANSLATION",
        "spise",
        "ecstasy",
        "ekstatisk",
        "opbyggelse",
        "uddanne",
        "uddannet",
        "uddannelsesmæssige",
        "effektiv",
        "virkningsfuldhed",
        "effektivitet",
        "effektiv",
        "indsats",
        "ejakulation",
        "udarbejdelse",
        "opstemt",
        "ældre",
        "ældste",
        "vælge",
        "elektrisk",
        "elektricitet",
        "elegance",
        "elegant",
        "elevation",
        "berettiget",
        "elite",
        "veltalenhed",
        "veltalende",
        "belyse",
        "frigørelse",
        "omfavne",
        "emeritus",
        "eminence",
        "fremtrædende",
        "eminent",
        "NO TRANSLATION",
        "empati",
        "bemyndige",
        "efterligne",
        "gøre det muligt for",
        "aktivering",
        "fortrylle",
        "fortryllet",
        "fortryllende",
        "NO TRANSLATION",
        "tilskynde",
        "opmuntring",
        "encyklopædi",
        "bestræbelse",
        "udstyre",
        "begavet",
        "begavelse",
        "udholdenhed",
        "udholde",
        "energisk",
        "beskæftiget",
        "engagerende",
        "forbedre",
        "god fornøjelse",
        "nyder",
        "oplyse",
        "oplysning",
        "oplive",
        "berige",
        "ensemble",
        "banner",
        "initiativrige",
        "underholde",
        "underholdt",
        "underholdende",
        "underholdning",
        "entusiasme",
        "entusiast",
        "NO TRANSLATION",
        "efemeride",
        "episk",
        "indbegrebet",
        "lighed",
        "ligeligt",
        "ligevægt",
        "egenkapital",
        "ærinde",
        "lærd",
        "esprit",
        "vigtig",
        "etableret",
        "agtelse",
        "æstetisk",
        "etisk",
        "etik",
        "stedsegrønne",
        "evig",
        "indlysende",
        "udvikling",
        "ophøje",
        "ophøjelse",
        "ophøjet",
        "overstige",
        "Excel",
        "ekspertise",
        "fremragende",
        "udveksling",
        "overgearet",
        "excitation",
        "ophidse",
        "begejstret",
        "spænding",
        "spændende",
        "eksemplarisk",
        "fritagelse",
        "opstemthed",
        "formane",
        "formaning",
        "eksistens",
        "eksotisk",
        "forventer",
        "forventning",
        "formålstjenligt",
        "ekspedition",
        "oplevet",
        "ekspert",
        "ekspertise",
        "forklare",
        "udsøgt",
        "udsøgt",
        "forlænge",
        "stor",
        "ekstra",
        "ekstraordinær",
        "vikle",
        "overflod",
        "lette",
        "fakta",
        "fakultet",
        "NO TRANSLATION",
        "retfærdig",
        "temmelig",
        "tro",
        "trofast",
        "berømmelse",
        "velkendt",
        "fortrolighed",
        "berømt",
        "berømt",
        "fancy",
        "fanfare",
        "spændende",
        "fascination",
        "på mode",
        "fejlfri",
        "gunstig",
        "favorit",
        "favorisering",
        "frygtløs",
        "bedrift",
        "funktion",
        "felicity",
        "fyr",
        "fællesskab",
        "kvinde",
        "frodige",
        "iver",
        "festival",
        "festlig",
        "NO TRANSLATION",
        "Troskab",
        "fiesta",
        "endelig",
        "stads",
        "finesse",
        "ildkugle",
        "brandsikker",
        "fasthed",
        "NO TRANSLATION",
        "montering",
        "armatur",
        "flatterende",
        "flåde",
        "fleksibilitet",
        "blomster",
        "flyde",
        "blomstrende",
        "Flush",
        "flyvende",
        "fokus",
        "forkærlighed",
        "mad",
        "fodbold",
        "overbærenhed",
        "forgrunden",
        "forfædre",
        "ovenstående",
        "værkfører",
        "forløber",
        "forudse",
        "planlagte",
        "fremsyn",
        "smede",
        "tilgive",
        "tilgivet",
        "tilgivende",
        "formativ",
        "formel",
        "NO TRANSLATION",
        "kommende",
        "forstærke",
        "fatning",
        "fæstning",
        "heldig",
        "formue",
        "frem",
        "fundet",
        "fundament",
        "duftende",
        "åben",
        "frimodighed",
        "broderlige",
        "frihed",
        "frit",
        "ven",
        "venlighed",
        "venlige",
        "venskab",
        "Felix",
        "løssluppenhed",
        "sparsommelige",
        "frugtbart",
        "opfylde",
        "opfyldelse",
        "fuld",
        "fuldt ud",
        "sjovt",
        "grundlæggende",
        "sikring",
        "fusion",
        "gevinst",
        "vinder",
        "galant",
        "tapperhed",
        "massevis",
        "have",
        "granat",
        "garnison",
        "Gazette",
        "gear",
        "perle",
        "generel",
        "gavmildhed",
        "gavmild",
        "genial",
        "geni",
        "standsmæssig",
        "gentleman",
        "mildhed",
        "landadel",
        "ægte",
        "geranium",
        "gave",
        "begavede",
        "gigantisk",
        "fnise",
        "bjælke",
        "giver",
        "glad",
        "glæde",
        "skadefryd",
        "svæve",
        "glimt",
        "glitrende",
        "forherligelse",
        "forherlige",
        "ære",
        "gloss",
        "glød",
        "glødende",
        "Gud",
        "gudfrygtig",
        "gave",
        "guld",
        "godt",
        "prægtigt",
        "godhed",
        "gods",
        "goodwill",
        "smukke",
        "evangelium",
        "styre",
        "nåde",
        "yndefuld",
        "nådig",
        "nådigt",
        "graduering",
        "børnebørn",
        "storhed",
        "bedstemor",
        "give",
        "bevilget",
        "taknemmelig",
        "tilfredsstille",
        "taknemmelighed",
        "større",
        "storhed",
        "grøn",
        "hilsen",
        "selskabelig",
        "grin",
        "grist",
        "grus",
        "fundament",
        "dyrke",
        "vækst",
        "garanti",
        "vagt",
        "værge",
        "værgemål",
        "guvernørvalget",
        "vejledning",
        "guide",
        "guidebog",
        "guru",
        "indvolde",
        "gymnast",
        "levested",
        "hale",
        "praktisk",
        "lykkeligt",
        "lykke",
        "lykkelig",
        "hårdfør",
        "harmonisk",
        "harmoni",
        "høst",
        "tilflugtssted",
        "Hovedvej",
        "hele",
        "healing",
        "sunde",
        "sund og rask",
        "inderligt",
        "arne",
        "hjerteligt",
        "himmelske",
        "himlen",
        "heft",
        "hjelm",
        "hjælper",
        "nyttig",
        "urte",
        "helt",
        "heroisk",
        "heroics",
        "heltinde",
        "heltemod",
        "velmagtsdage",
        "hysterisk morsom",
        "munterhed",
        "leje",
        "hobby",
        "ferie",
        "hellighed",
        "hellig",
        "hyldest",
        "homologi",
        "ærlig",
        "ærlighed",
        "honning",
        "bryllupsrejse",
        "ære",
        "hæderlig",
        "håber",
        "håbefuld",
        "horisont",
        "gæstfrihed",
        "husstand",
        "husholdning",
        "knus",
        "human",
        "humanitær",
        "menneskelighed",
        "ydmyget",
        "ydmygt",
        "ydmyghed",
        "humorist",
        "humoristisk",
        "hurra",
        "dyrehold",
        "stille",
        "hytte",
        "hygiejnisk",
        "salme",
        "idealisme",
        "idol",
        "NO TRANSLATION",
        "belysning",
        "illustrere",
        "hæderkronede",
        "fantasifulde",
        "ulastelig",
        "umådelig",
        "fordybe",
        "udødelig",
        "bibringe",
        "upartisk",
        "upartiskhed",
        "upåklagelig",
        "uigennemtrængelig",
        "betydning",
        "vigtig",
        "imponere",
        "indtryk",
        "forbedre",
        "forbedret",
        "forbedring",
        "forbedring",
        "improvisere",
        "umistelig",
        "indvielse",
        "skarp",
        "omfatte",
        "inkluderet",
        "inklusive",
        "inklusive",
        "øge",
        "uudslettelig",
        "godtgørelse",
        "uafhængighed",
        "uforgængelige",
        "individualitet",
        "ukuelig",
        "uudsigelige",
        "billig",
        "ufejlbarlig",
        "spædbarn",
        "uendelig",
        "uendelighed",
        "indflydelsesrig",
        "information",
        "genial",
        "arv",
        "uforligneligt",
        "uskyld",
        "uskyldig",
        "uskyldigt",
        "harmløs",
        "innovere",
        "innovation",
        "Inquirer",
        "forespørgsel",
        "nysgerrig",
        "uadskillelige",
        "insignier",
        "inspektør",
        "inspiration",
        "inspirere",
        "inspireret",
        "instinktiv",
        "instruere",
        "instruktion",
        "instruktør",
        "medvirkende",
        "forsikre",
        "intakt",
        "integritet",
        "intellekt",
        "intellektuel",
        "intelligens",
        "intelligent",
        "beregnet",
        "samleje",
        "interesse",
        "interesseret",
        "interessant",
        "interiør",
        "foreløbige",
        "mellemspil",
        "intim",
        "intonation",
        "Intrepid",
        "intuition",
        "intuitiv",
        "uvægerligt",
        "opfindsomme",
        "opfinder",
        "undersøge",
        "puste nyt liv",
        "invitation",
        "invitere",
        "indbydende",
        "jern",
        "irreducible",
        "uigendrivelige",
        "jackpot",
        "marmelade",
        "NO TRANSLATION",
        "job",
        "tilslutte",
        "sluttede",
        "joker",
        "laver sjov",
        "journalist",
        "rejse",
        "jovial",
        "glæde",
        "glad",
        "glad",
        "jublende",
        "jubilæum",
        "retslige",
        "velovervejet",
        "hoppe",
        "retfærdighed",
        "berettiget",
        "begrundelse",
        "souvenir",
        "ken",
        "keynote",
        "slutsten",
        "venlig",
        "venlighed",
        "beslægtet",
        "konge",
        "kys",
        "killing",
        "håndelag",
        "ridder",
        "kende",
        "viden",
        "kudos",
        "arbejdskraft",
        "lam",
        "jord",
        "landet",
        "laser",
        "prisværdigt",
        "grine",
        "griner",
        "latter",
        "lancering",
        "prismodtageren",
        "laurbær",
        "laurbær",
        "overdådige",
        "lovlig",
        "at føre",
        "leder",
        "liga",
        "lære",
        "læring",
        "foredragsholder",
        "spillerum",
        "gyldige",
        "legaliseret",
        "legendariske",
        "læsbarhed",
        "læselig",
        "fritid",
        "afslappet",
        "lemma",
        "lempelig",
        "lektie",
        "lettered",
        "niveau",
        "gearing",
        "befri",
        "befrielse",
        "frihed",
        "bibliotek",
        "hjerteblod",
        "fyrtårn",
        "smag",
        "lingvist",
        "løve",
        "smidig",
        "logisk",
        "lang levetid",
        "herredømme",
        "elskelig",
        "elsker",
        "dejlig",
        "NO TRANSLATION",
        "elsker",
        "kærlig",
        "loyal",
        "loyalitet",
        "held",
        "heldig",
        "saftig",
        "glans",
        "skinnende",
        "frodig",
        "luksuriøs",
        "luksus",
        "lyre",
        "lyriske",
        "magiske",
        "magnet",
        "magnetisme",
        "magnetit",
        "pragt",
        "storslået",
        "jomfru",
        "vigtigste",
        "grundpille",
        "majestætisk",
        "majestæt",
        "større",
        "flertal",
        "styre",
        "ledelse",
        "mandarin",
        "manddom",
        "manifesteret",
        "mandig",
        "manna",
        "manierede",
        "manerer",
        "fabrikant",
        "marts",
        "markeret",
        "omsættelige",
        "Marquis",
        "ægteskab",
        "marv",
        "gifte",
        "marskal",
        "vidunder",
        "vidunderlig",
        "vidunderligt",
        "maskulin",
        "massage",
        "mestre",
        "mesterværk",
        "beherskelse",
        "parrer sig",
        "ægteskab",
        "økonoma",
        "maksimum",
        "borgmester",
        "eng",
        "målt",
        "medalje",
        "mediere",
        "mægling",
        "mediator",
        "medicinsk",
        "NO TRANSLATION",
        "middelhavet",
        "medley",
        "Memento",
        "mindeværdige",
        "lapning",
        "menstruation",
        "mentor",
        "barmhjertig",
        "barmhjertighed",
        "fusionere",
        "fortjeneste",
        "fortjenstfulde",
        "lystighed",
        "lystig",
        "hovedstadsområdet",
        "fyrighed",
        "mikroskopi",
        "fødselshjælp",
        "mægtig",
        "mime",
        "opmærksomme",
        "mindfulness",
        "ministerium",
        "mirakel",
        "mirakuløs",
        "munterhed",
        "missionær",
        "model",
        "moderat",
        "moderator",
        "beskedne",
        "beskedenhed",
        "momentum",
        "monetære",
        "penge",
        "munk",
        "monument",
        "moralsk",
        "moral",
        "moral",
        "mørtel",
        "moderskab",
        "motiv",
        "bevægelig",
        "mover",
        "muskuløs",
        "musik",
        "musikalsk",
        "foranderlig",
        "gensidig",
        "lur",
        "naturforsker",
        "sejlbar",
        "pænt",
        "nektar",
        "nål",
        "forhandle",
        "forhandler",
        "nabo",
        "nerve",
        "nestle",
        "adel",
        "adelig",
        "adelsmand",
        "nominering",
        "normalitet",
        "bemærkelsesværdig",
        "notabiliteter",
        "NO TRANSLATION",
        "begreb",
        "næring",
        "numre",
        "amme",
        "planteskole",
        "pleje",
        "nærende",
        "egetræ",
        "oase",
        "ed",
        "lydighed",
        "objektiv",
        "imødekommende",
        "opmærksom",
        "opnåelig",
        "indlysende",
        "beboer",
        "beskæftigelse",
        "besætte",
        "tilbud",
        "officer",
        "offset",
        "udløber",
        "alvidende",
        "åbenhed",
        "opera",
        "opportunt",
        "lejlighed",
        "optimisme",
        "optimist",
        "mulighed",
        "valgfri",
        "oracle",
        "Tale",
        "orkester",
        "ordineret",
        "velordnet",
        "ordination",
        "organisk",
        "organisation",
        "organisere",
        "organiseret",
        "orgasme",
        "originalitet",
        "ornamenterede",
        "udsmykkede",
        "resultat",
        "overgå",
        "udgående",
        "himmelhenrykt",
        "overvældende",
        "ejendomsret",
        "pacific",
        "pad",
        "polstring",
        "padle",
        "spiselig",
        "palliativ",
        "universalmiddel",
        "flot stil",
        "NO TRANSLATION",
        "paprika",
        "dydsmønster",
        "altoverskyggende",
        "om forladelse",
        "herkomst",
        "parietal",
        "deltage",
        "deltagelse",
        "partner",
        "partnerskab",
        "lidenskab",
        "lidenskabelig",
        "tidsfordriv",
        "pastor",
        "bagværk",
        "græs",
        "patent",
        "tålmodighed",
        "patient",
        "patriarkalske",
        "protektor",
        "protektion",
        "betale",
        "fred",
        "fredelige",
        "fredelig",
        "påfugl",
        "peck",
        "ejendommelighed",
        "stamtavle",
        "uden lige",
        "forkærlighed",
        "erkende",
        "mærkbar",
        "staude",
        "Perfekt",
        "fuldkommenhed",
        "performer",
        "frynsegode",
        "tilladelse",
        "evighed",
        "udholdenhed",
        "vedvarende",
        "nacn",
        "relevant",
        "farmaceutisk",
        "filantrop",
        "filantropi",
        "filosof",
        "phoenix",
        "fonetisk",
        "læge",
        "fysik",
        "fysiologi",
        "fysik",
        "plukke",
        "picnic",
        "maleriske",
        "fromhed",
        "pille",
        "pude",
        "pilot",
        "tinde",
        "pioner",
        "fromme",
        "marv",
        "omdrejningspunkt",
        "fredsommelig",
        "planlægning",
        "legende",
        "legeplads",
        "legehus",
        "behagelig",
        "tilfreds",
        "lystbetonet",
        "løfte",
        "plenum",
        "rigelig",
        "plexus",
        "blomme",
        "lod",
        "plys",
        "lags",
        "spidst",
        "politi",
        "politibetjent",
        "polere",
        "poleret",
        "høflig",
        "høflighed",
        "NO TRANSLATION",
        "pool",
        "pave",
        "popularitet",
        "populariseret",
        "befolkning",
        "transportabel",
        "have",
        "drikkevand",
        "potens",
        "magtfulde",
        "effektfuldt",
        "øve sig",
        "praktiseres",
        "øve sig",
        "ros",
        "rost",
        "rosværdigt",
        "bede",
        "forsigtighed",
        "gå forud",
        "forrang",
        "kostbar",
        "præcis",
        "præcision",
        "forkærlighed",
        "dominerende",
        "fremtrædende",
        "foretrække",
        "premier",
        "lokaliteter",
        "forberede",
        "forberedt",
        "forudseende",
        "tilstedeværelse",
        "til stede",
        "præsentabel",
        "konserveringsmiddel",
        "bevare",
        "formand",
        "prestige",
        "presto",
        "smuk",
        "være fremherskende",
        "forebyggelse",
        "uvurderlig",
        "stolthed",
        "præst",
        "præstedømme",
        "præstelige",
        "forrang",
        "primær",
        "prime",
        "primer",
        "prins",
        "fyrstelige",
        "prinsesse",
        "rektor",
        "uberørt",
        "privilegeret",
        "redelighed",
        "procedure",
        "procession",
        "Proctor",
        "skaffe",
        "uhyre",
        "vidunderbarn",
        "producent",
        "producerer",
        "produktion",
        "produktiv",
        "produktivitet",
        "erhverv",
        "professionel",
        "professor",
        "sprogfærdighed",
        "dygtig",
        "rigelig",
        "fremskridt",
        "progression",
        "progressiv",
        "frodig",
        "fremtrædende",
        "fremtrædende",
        "løfte",
        "lovende",
        "forfremmelse",
        "rekvisit",
        "passende",
        "profet",
        "profylaktisk",
        "forslag",
        "udsigt",
        "trives",
        "velstand",
        "blomstrende",
        "beskytte",
        "beskyttelse",
        "beskyttende",
        "protektor",
        "stolt",
        "bevise",
        "legendariske",
        "give",
        "at sørge for",
        "forsigtighed",
        "forsigtig",
        "salme",
        "offentlig",
        "trække",
        "prædikestol",
        "punktlig",
        "punktlighed",
        "hundehvalp",
        "rent",
        "oprensning",
        "rense",
        "puristiske",
        "renhed",
        "spinde",
        "maleriske",
        "kvalificeret",
        "kvalificerende",
        "søgen",
        "spørgsmål",
        "hurtighed",
        "hvilestrøm",
        "rolige",
        "kinin",
        "udstråling",
        "strålende",
        "udstråle",
        "radio",
        "åndeløs",
        "ekstase",
        "rationel",
        "læser",
        "let",
        "parathed",
        "læsning",
        "bekræfte",
        "ægte",
        "grund",
        "forsikring",
        "berolige",
        "rabat",
        "omarbejdning",
        "modtaget",
        "modtager",
        "NO TRANSLATION",
        "gengælde",
        "regenerering",
        "læne sig tilbage",
        "genkendelige",
        "anbefale",
        "forsoning",
        "revurdering",
        "rekonstruere",
        "rekonstruktion",
        "optager",
        "forrente",
        "genopretning",
        "rekreation",
        "rekreative",
        "rette",
        "frelse",
        "oprejsning",
        "raffinere",
        "raffinement",
        "reform",
        "reformation",
        "reformator",
        "forfriskende",
        "renovere",
        "regal",
        "regent",
        "regelmæssighed",
        "regulere",
        "rehabilitere",
        "rehabilitering",
        "tilbagebetale",
        "refusion",
        "forstærkning",
        "genindføre",
        "Glæd dig",
        "jubel",
        "forynge",
        "forynget",
        "lempelse",
        "relevant",
        "pålidelighed",
        "pålidelig",
        "afhængighed",
        "lettelse",
        "lindre",
        "genindspilning",
        "bemærkelsesværdig",
        "NO TRANSLATION",
        "afhjælpe",
        "remission",
        "remodel",
        "renæssance",
        "gengive",
        "fornyelse",
        "forny",
        "renovation",
        "berømmelse",
        "berømt",
        "reorganisere",
        "erstatning",
        "tilbagebetale",
        "angre",
        "genopbygge",
        "propfuld",
        "reporter",
        "hvile",
        "repræsenteret",
        "reproduktive",
        "velrenommeret",
        "redde",
        "reservere",
        "bosiddende",
        "robust",
        "resistiv",
        "resolut",
        "ressourcer",
        "respekt",
        "respektabilitet",
        "respektabel",
        "respektfuld",
        "respekt",
        "henseender",
        "pusterum",
        "strålende",
        "ansvarlig",
        "lydhør",
        "hvile",
        "rolig",
        "tilbagelevering",
        "genoprettende",
        "genoprette",
        "tilbageholdenhed",
        "genoptagelse",
        "tilbageholdelse",
        "genforening",
        "svælge",
        "svælger",
        "Revere",
        "ærbødighed",
        "ærværdige",
        "drømmeri",
        "revidere",
        "genoplivning",
        "revolutionerende",
        "belønning",
        "rytme",
        "rytmisk",
        "bånd",
        "rigdom",
        "rytter",
        "retfærdig",
        "retmæssige",
        "rette",
        "moden",
        "modnes",
        "stigende",
        "nitning",
        "roadster",
        "robust",
        "klippe",
        "stang",
        "overstadig",
        "romantik",
        "romantisk",
        "romantik",
        "tumle",
        "rødder",
        "rosenrødt",
        "rota",
        "rutine",
        "royalty",
        "rubrik",
        "ruth",
        "sikker",
        "værne",
        "salvie",
        "helgen",
        "hellig",
        "løn",
        "fremtrædende",
        "gavnlig",
        "salut",
        "frelse",
        "salve",
        "samurai",
        "helliggørelse",
        "helliggøre",
        "fristed",
        "sangvinsk",
        "sanitære",
        "satin",
        "tilfredsstillende",
        "tilfreds",
        "Gemme",
        "opsparing",
        "Duft",
        "krydrede",
        "kyndige",
        "lærd",
        "stipendium",
        "videnskabelig",
        "videnskabsmand",
        "NO TRANSLATION",
        "score",
        "skriftlærde",
        "manuskript",
        "lækker",
        "skulptur",
        "hav",
        "forsegle",
        "krydret",
        "sekretariatet",
        "anciennitet",
        "sensationel",
        "følelse",
        "følsomhed",
        "fornuftigt",
        "sensualitet",
        "sanselige",
        "sentimental",
        "sentimentalitet",
        "sentinel",
        "sindsro",
        "prædiken",
        "serum",
        "stifter",
        "køn",
        "form",
        "velskabt",
        "del",
        "ly",
        "fårehyrde",
        "skinne",
        "skinner",
        "handle ind",
        "skulder",
        "snu",
        "silke",
        "forenkle",
        "oprigtig",
        "oprigtighed",
        "synge",
        "enkeltvis",
        "hr",
        "søsterskab",
        "faglært",
        "dygtige",
        "himmel",
        "skifer",
        "slank",
        "slank",
        "slank",
        "smil",
        "smilende",
        "slået",
        "glathed",
        "snicker",
        "ædruelighed",
        "omgængelig",
        "trøst",
        "soldat",
        "solid",
        "soliditet",
        "løsning",
        "solvens",
        "sonar",
        "sonate",
        "Sonnet",
        "klangfuld",
        "at lindre",
        "beroligende",
        "NO TRANSLATION",
        "soliditet",
        "suppe",
        "spa",
        "rummelig",
        "spaniel",
        "glimte",
        "særlig",
        "NO TRANSLATION",
        "tale",
        "hurtig",
        "stavning",
        "krydderi",
        "ånd",
        "spiritus",
        "glimrende",
        "pragt",
        "sponsor",
        "pletfri",
        "ægtefælle",
        "gran",
        "stabil",
        "staccato",
        "rustfri",
        "hingst",
        "gæv",
        "udholdenhed",
        "stående",
        "stjerne",
        "stjernelys",
        "stjerneklar",
        "statelige",
        "udmelding",
        "statue",
        "status",
        "standhaftig",
        "standhaftige",
        "stjernernes",
        "steward",
        "Stilhed",
        "butik",
        "ligetil",
        "strategisk",
        "strateg",
        "styrke",
        "styrke",
        "styrkelse",
        "slående",
        "påfaldende",
        "stærkt",
        "struktur",
        "stud",
        "undersøgelse",
        "robust",
        "sublimering",
        "stof",
        "materielle",
        "lykkes",
        "efterfølgende",
        "succes",
        "vellykket",
        "kortfattet",
        "selvforsyning",
        "sukker",
        "egnet",
        "lummer",
        "sol",
        "solrig",
        "solnedgang",
        "solskin",
        "superb",
        "overmenneskelig",
        "overlegen",
        "overlegenhed",
        "superman",
        "superstar",
        "bøn",
        "forsyninger",
        "levere",
        "understøttet",
        "supporter",
        "støtte",
        "supreme",
        "suverænt",
        "kaution",
        "formode",
        "overgår",
        "overraskelse",
        "opmåling",
        "overleve",
        "sværge",
        "sød",
        "kæreste",
        "søde",
        "sødme",
        "søde sager",
        "swift",
        "svømme",
        "symbolsk",
        "symmetrisk",
        "symmetri",
        "sympatisk",
        "sympati",
        "symfoni",
        "synkronisere",
        "synergistiske",
        "synode",
        "takt",
        "fortælling",
        "talent",
        "talisman",
        "tale",
        "garvet",
        "opgave",
        "smagfuld",
        "velsmagende",
        "underviser",
        "lærer",
        "teknologi",
        "mådehold",
        "hærdet",
        "holdbar",
        "ihærdige",
        "vedholdenhed",
        "lejemål",
        "lejer",
        "bud",
        "ømhed",
        "taknemmelig",
        "taksigelse",
        "teoretisk",
        "terapeutisk",
        "terapi",
        "NO TRANSLATION",
        "fuldblods",
        "tankevækkende",
        "eftertænksomhed",
        "sparsommelighed",
        "gys",
        "spændende",
        "blomstrende",
        "trone",
        "kildre",
        "flisebelægning",
        "rettidig",
        "lametta",
        "titel",
        "ristet brød",
        "tolerant",
        "tolerance",
        "top",
        "sejhed",
        "tårn",
        "tårnhøje",
        "traditionel",
        "rolig",
        "ro",
        "transcendens",
        "transcendental",
        "rejsende",
        "skat",
        "træ",
        "uhyre",
        "trend",
        "smarte",
        "biflod",
        "hyldest",
        "trig",
        "triumf",
        "Triumferende",
        "trofæ",
        "våbenstilstand",
        "RIGTIGT",
        "trofaste",
        "sandhed",
        "sandfærdighed",
        "formynderskab",
        "vejleder",
        "tvilling",
        "twinkle",
        "ultimativt",
        "opmand",
        "enstemmighed",
        "enstemmig",
        "fordringsløs",
        "fordomsfri",
        "ubrydelig",
        "ubrudt",
        "uhindret",
        "understrege",
        "forståelse",
        "garantere",
        "udelt",
        "udødelige",
        "utvetydigt",
        "udfolde",
        "forening",
        "ensartet",
        "inficerede",
        "enestående",
        "kor",
        "ét stykke",
        "forenet",
        "enhed",
        "universitet",
        "ubegrænset",
        "uhøjtidelig",
        "ubestridelige",
        "utvivlsomt",
        "ubestridt",
        "uskadt",
        "uselvisk",
        "uovertruffen",
        "urokkelige",
        "hævning",
        "oprejst",
        "anvendelighed",
        "indvarsle",
        "sædvanlig",
        "nytte",
        "utopisk",
        "ferie",
        "vaccine",
        "tapper",
        "NO TRANSLATION",
        "værdifuld",
        "fortrop",
        "besejre",
        "fløjl",
        "fløjlsagtig",
        "ærværdige",
        "veneration",
        "sandfærdighed",
        "grønne",
        "verifikation",
        "verificeres",
        "sandelig",
        "veritabel",
        "Vernal",
        "verve",
        "veteran",
        "sognepræst",
        "victor",
        "sejrende",
        "sejr",
        "årvågenhed",
        "vagt",
        "vigør",
        "energisk",
        "landsbybeboer",
        "retfærdiggjort",
        "vindication",
        "jomfru",
        "jomfruelighed",
        "dyd",
        "dydige",
        "vision",
        "visionær",
        "besøg",
        "besøgende",
        "vital",
        "vitalitet",
        "livlig",
        "levende",
        "ordforråd",
        "frivillig",
        "vellystig",
        "stå inde",
        "løfte",
        "løn",
        "garanti",
        "kriger",
        "vagthund",
        "vagtsom",
        "vægter",
        "vandtæt",
        "rigdom",
        "vejrbestandig",
        "hilste",
        "hvid",
        "hvidhed",
        "sund",
        "gærde",
        "udbredt",
        "villigt",
        "villighed",
        "stormfald",
        "vinder",
        "vinder",
        "gevinster",
        "trådløs",
        "Wis",
        "visdom",
        "klog",
        "Vid",
        "modstå",
        "forstand",
        "vittig",
        "guiden",
        "livmoder",
        "vidunderlig",
        "vidunderligt",
        "vidunderlige",
        "ord",
        "arbejder",
        "tilbede",
        "værdi",
        "værdig",
        "wot",
        "forfatter",
        "ung",
        "yngre",
        "ungdom",
        "iver",
        "ivrig",
        "citronskal",
    ]
)

_negative = set(
    [
        "opgive",
        "forladt",
        "opgivelse",
        "bortførelse",
        "afvigende",
        "aberration",
        "afskyr",
        "afskyeligt",
        "ynkelig",
        "abnorm",
        "afskaffe",
        "afskaffelsen",
        "vederstyggelige",
        "vederstyggelighed",
        "abort",
        "abort",
        "forfejlede",
        "slid",
        "ophæver",
        "byld",
        "fravær",
        "fraværende",
        "fraværende",
        "fravær",
        "absurd",
        "absurditet",
        "misbrug",
        "afgrundsdyb",
        "afgrunden",
        "ulykke",
        "tilfældig",
        "forbandede",
        "anklage",
        "akkusativ",
        "anklagede",
        "anklager",
        "beskylder",
        "smerte",
        "smertende",
        "syre",
        "handlingsrettede",
        "adder",
        "afhængighed",
        "fedtvæv",
        "træffe afgørelse i sagen",
        "formaning",
        "adrift",
        "forfalsket",
        "ægteskabsbrud",
        "modstander",
        "ugunstig",
        "modgang",
        "plage",
        "ramt",
        "lidelse",
        "krænkelse",
        "bange",
        "kølvandet",
        "eftersmag",
        "forværret",
        "forværret",
        "forværring",
        "aggression",
        "aggressiv",
        "aggressor",
        "forfærdet",
        "ophidsede",
        "agitation",
        "pinefuld",
        "smerte",
        "grundstødte",
        "Ail",
        "skrantende",
        "formålsløs",
        "airs",
        "alarm",
        "alarmerende",
        "alkoholisme",
        "alien",
        "fremmedgøre",
        "fremmedgjorte",
        "fremmedgørelse",
        "underholdsbidrag",
        "påstand",
        "påstår",
        "tilknappet",
        "skænderi",
        "tvetydig",
        "baghold",
        "amnesi",
        "amfetamin",
        "anaconda",
        "anal",
        "anarkisme",
        "anarkist",
        "anarki",
        "bandlyst",
        "gammel",
        "vrede",
        "angina",
        "lystfiskeri",
        "vred",
        "kvaler",
        "fjendskab",
        "animus",
        "tilintetgøre",
        "tilintetgjort",
        "tilintetgørelse",
        "irritere",
        "irritation",
        "irriterende",
        "annullere",
        "annullation",
        "anomali",
        "anonym",
        "antagonisme",
        "modstander",
        "antagonistiske",
        "miltbrand",
        "Antikrist",
        "antipati",
        "antikveret",
        "asocial",
        "antitese",
        "angst",
        "ængstelig",
        "apache",
        "apatisk",
        "apati",
        "bladlus",
        "rystende",
        "blindtarmsbetændelse",
        "ængstelse",
        "betænkelig",
        "bevilling",
        "gammeldags",
        "besværlig",
        "argumentere",
        "argument",
        "argumenterende",
        "tørre",
        "våben",
        "anklage",
        "restance",
        "anholdelse",
        "arrogance",
        "arrogant",
        "arsen",
        "brandstiftelse",
        "artilleri",
        "aske",
        "skamme sig",
        "aske",
        "røv",
        "angribe",
        "voldsmand",
        "snigmorder",
        "myrde",
        "snigmord",
        "angreb",
        "røvhul",
        "på afveje",
        "astringerende",
        "asyl",
        "ateisme",
        "åreforkalkning",
        "grusomme",
        "grusomhed",
        "atrofi",
        "angreb",
        "angribe",
        "svækket",
        "dæmpning",
        "dristighed",
        "barsk",
        "nøjsomhed",
        "autokratisk",
        "obduktion",
        "lavine",
        "griskhed",
        "hævner",
        "utilbøjelig",
        "aversion",
        "undgå",
        "undgåelse",
        "forfærdelig",
        "kejtethed",
        "skævt",
        "pludre",
        "pludrende",
        "bavian",
        "baglæns",
        "tilbage",
        "dødvande",
        "bakterie",
        "NO TRANSLATION",
        "dårlig",
        "grævling",
        "dårligt",
        "ondskab",
        "foged",
        "lokkemad",
        "balle",
        "Balk",
        "NO TRANSLATION",
        "bandit",
        "bane",
        "bang",
        "banger",
        "forjage",
        "forvist",
        "landsforvisning",
        "bankerot",
        "konkurs",
        "Banshee",
        "modhager",
        "barbar",
        "barbarisk",
        "barbari",
        "bark",
        "spærret",
        "ufrugtbar",
        "barrikade",
        "barriere",
        "grundløse",
        "skiderik",
        "dej",
        "voldsramte",
        "batteri",
        "kamp",
        "kæmpet",
        "slagmark",
        "sjofel",
        "bajonet",
        "ihændehaver",
        "dyr",
        "væmmelig",
        "prygl",
        "tilstøde",
        "tigge",
        "tigger",
        "tigger",
        "behemoth",
        "afhængighedsforhold",
        "forsinket",
        "forklejne",
        "krigsførende",
        "bælte",
        "Bender",
        "efterladte",
        "dødsfald",
        "blottet",
        "amok",
        "dyrisk",
        "forråde",
        "forræderi",
        "pas på",
        "Forvirret",
        "partiskhed",
        "forudindtaget",
        "skænderier",
        "NO TRANSLATION",
        "selvretfærdig",
        "bigot",
        "galde",
        "biopsi",
        "birk",
        "fødested",
        "tæve",
        "bid",
        "bittert",
        "bitterhed",
        "bizar",
        "sort",
        "blackjack",
        "afpresse",
        "sorthed",
        "bebrejde",
        "kedelig",
        "blasfemisk",
        "blasfemi",
        "blast",
        "åbenlys",
        "blather",
        "blis",
        "dyster",
        "blødende",
        "skamplet",
        "afsvide",
        "ødelagt",
        "blind",
        "blindet",
        "blindt",
        "blindhed",
        "vabel",
        "oppustet",
        "klat",
        "blokade",
        "blodsudgydelse",
        "blodtørstige",
        "blodig",
        "blottet",
        "blæser",
        "blowout",
        "blues",
        "bluff",
        "bommert",
        "sløring",
        "sløret",
        "rødme",
        "pral",
        "mose",
        "fup",
        "koge",
        "standardtekst",
        "bombe",
        "bombardere",
        "bombardement",
        "bombet",
        "trældom",
        "obligationer",
        "bøh",
        "booby",
        "sprut",
        "NO TRANSLATION",
        "kedsomhed",
        "kedelig",
        "låntager",
        "forstyrre",
        "generer",
        "bund",
        "bundet",
        "Bout",
        "kvæg",
        "dreng",
        "boykot",
        "prale",
        "brandy",
        "bravado",
        "slagsmål",
        "fræk",
        "brud",
        "sammenbrud",
        "halsbrækkende",
        "NO TRANSLATION",
        "bestikke",
        "bestikkelse",
        "brigade",
        "svovl",
        "stritter",
        "bredside",
        "stege",
        "gik i stykker",
        "gået i stykker",
        "bordel",
        "blåt mærke",
        "hovedparten",
        "brutal",
        "brutalitet",
        "brute",
        "buffet",
        "insekt",
        "NO TRANSLATION",
        "løgformet",
        "Bølle",
        "vagabond",
        "øv bøv",
        "belastende",
        "bureaukrati",
        "bureaukrat",
        "indbrudstyv",
        "indbrudstyveri",
        "begravelse",
        "begravet",
        "Burke",
        "brændt",
        "busted",
        "slagter",
        "røv",
        "summede",
        "klike",
        "kakofoni",
        "cad",
        "kadaver",
        "bur",
        "beregning",
        "NO TRANSLATION",
        "opkald",
        "valgkamp",
        "afbestille",
        "Kræft",
        "fordærve",
        "kannibal",
        "kannibalisme",
        "NO TRANSLATION",
        "fange",
        "fangenskab",
        "fangevogter",
        "fange",
        "slagtekrop",
        "carcinom",
        "kardiomyopati",
        "ligegyldighed",
        "karikatur",
        "caries",
        "blodbad",
        "kødelige",
        "kødædende",
        "kartel",
        "sag",
        "skrin",
        "kaste",
        "tilskadekomne",
        "grå stær",
        "katastrofe",
        "kateter",
        "Advarsel",
        "afstå",
        "kirkegård",
        "censor",
        "kritisere",
        "CESS",
        "ophør",
        "avner",
        "gnidning",
        "ærgrelse",
        "udfordring",
        "kaos",
        "kaotisk",
        "paradeforestilling",
        "gebyr",
        "jage",
        "revselse",
        "snakkesalig",
        "billig",
        "snyde",
        "ostekage",
        "chikane",
        "barnlig",
        "kølig",
        "chloroform",
        "kvæle",
        "kolera",
        "hakke",
        "sur pligt",
        "kronisk",
        "cigaret",
        "protester",
        "sammenstød",
        "modstridende",
        "klo",
        "kloster",
        "forplumret",
        "uklarhed",
        "klump",
        "klodset",
        "kokain",
        "tvinge",
        "tvang",
        "kiste",
        "kold",
        "koldt",
        "kulde",
        "kolik",
        "bryder sammen",
        "kollision",
        "aftalt spil",
        "koma",
        "koma",
        "bekæmpe",
        "kombattant",
        "kampklar",
        "forpligtende",
        "tumult",
        "kommunisme",
        "kommunist",
        "konkurrence",
        "brokke sig",
        "klage",
        "kompleksdannede",
        "kompleksitet",
        "komplicere",
        "kompliceret",
        "komplikation",
        "kompost",
        "tvang",
        "obligatorisk",
        "skjule",
        "skjult",
        "fortielse",
        "indbildskhed",
        "indbildsk",
        "hjernerystelse",
        "fordømme",
        "fordømmelse",
        "Nedladende",
        "nedladenhed",
        "tilståelse",
        "begrænse",
        "begrænset",
        "indespærring",
        "konfiskere",
        "konfiskation",
        "storbrand",
        "konflikt",
        "modstridende",
        "forvirre",
        "beskæmmet",
        "forvirre",
        "forvirring",
        "overbelastning",
        "trylle",
        "erobring",
        "medsammensvoren",
        "konspirerer",
        "bestyrtelse",
        "forstoppelse",
        "begrænse",
        "hæmmet",
        "tvang",
        "afsmitning",
        "smitsom",
        "forurene",
        "kontamineret",
        "forurening",
        "foragt",
        "foragtelig",
        "foragtende",
        "omstridt",
        "kontrabande",
        "kontraheret",
        "modsige",
        "modsigelse",
        "modstridende",
        "modsætning",
        "kontrast",
        "strid",
        "strid",
        "kontroversielle",
        "kontrovers",
        "straffefange",
        "Domfældelse",
        "samarbejde",
        "kopi",
        "copycat",
        "retsmediciner",
        "korporal",
        "lig",
        "rettelse",
        "korrosion",
        "ætsende",
        "korrupt",
        "korrumperende",
        "korruption",
        "hoste",
        "rådgiver",
        "coursing",
        "begære",
        "kujon",
        "fejhed",
        "fej",
        "gnavne",
        "sprække",
        "revnet",
        "revner",
        "krampe",
        "trange",
        "krank",
        "mærkelig",
        "lort",
        "krak",
        "kravle",
        "forrykte",
        "helt vildt",
        "knirkende",
        "væsen",
        "krybe",
        "forbrydelse",
        "kriminel",
        "kriminalitet",
        "krybe",
        "krøbling",
        "forkrøblede",
        "krise",
        "sprød",
        "kritiker",
        "kritik",
        "kritisere",
        "skurk",
        "kryds",
        "crouching",
        "korsbånd",
        "korsfæstelse",
        "rå",
        "grusom",
        "grusomt",
        "grusomhed",
        "smuldre",
        "stykket",
        "korstog",
        "knust",
        "knusning",
        "crusty",
        "skrig",
        "græder",
        "krypt",
        "hanrej",
        "gøg",
        "frasortering",
        "skyld",
        "skyldig",
        "synderen",
        "kult",
        "besværlig",
        "cupping",
        "cur",
        "forbande",
        "forbandet",
        "forbandelse",
        "overfladisk",
        "kutter",
        "skarp",
        "skæring",
        "cyanid",
        "cyklon",
        "cyste",
        "cytomegalovirus",
        "dabbling",
        "dæmon",
        "dum",
        "dolk",
        "skade",
        "skader",
        "for pokker",
        "forbandelse",
        "forbandet",
        "dæmper",
        "skæl",
        "dandy",
        "fare",
        "farligt",
        "mørkere",
        "formørket",
        "mørke",
        "stiplet",
        "nedrige",
        "fortumlet",
        "deaktivere",
        "dødvande",
        "dødelig",
        "døv",
        "død",
        "fiaskoen",
        "skørlevned",
        "vragrester",
        "gæld",
        "debitor",
        "henfald",
        "henfaldet",
        "afdød",
        "bedrag",
        "bedragerisk",
        "bedrage",
        "bedraget",
        "bedrager",
        "bedrag",
        "vildledende",
        "deklination",
        "nedgang",
        "faldende",
        "nedbrydning",
        "formindske",
        "formindskelsen",
        "affældig",
        "nedvurderer",
        "fradrage",
        "ærekrænkelse",
        "ærekrænkende",
        "Standard",
        "nederlag",
        "besejret",
        "defekt",
        "NO TRANSLATION",
        "defekt",
        "forsvarsløse",
        "udskydelse",
        "trodsighed",
        "trodsig",
        "mangel",
        "underskud",
        "punktere",
        "deflation",
        "deformere",
        "deform",
        "deformitet",
        "bedrage",
        "hedengangne",
        "trodse",
        "degeneration",
        "degenereret",
        "nedbrydning",
        "nedbryde",
        "nedværdigende",
        "forsinke",
        "forsinket",
        "skadelig",
        "sletning",
        "ungdomskriminalitet",
        "kriminel",
        "ellevild",
        "delirium",
        "syndflod",
        "vrangforestilling",
        "vrangforestilling",
        "efterspørgsel",
        "krævende",
        "dement",
        "demens",
        "død",
        "nedrive",
        "nedrivning",
        "dæmon",
        "dæmonisk",
        "demoraliseret",
        "afslag",
        "nægtet",
        "opsige",
        "opsigelse",
        "nægte",
        "benægte",
        "afgået",
        "afgang",
        "afhængighed",
        "afhængighed",
        "beklageligt",
        "beklage",
        "deportere",
        "udvisning",
        "fordærvet",
        "fordærvelse",
        "afskrive",
        "afskrives",
        "afskrivninger",
        "trykke",
        "deprimeret",
        "deprimerende",
        "depression",
        "depressive",
        "afsavn",
        "sindsforvirret",
        "forladte",
        "hån",
        "dispensation",
        "nedsættende",
        "vanhelligelse",
        "ørken",
        "øde",
        "desertion",
        "afstå",
        "trøstesløshed",
        "fortvivlelse",
        "fortvivlet",
        "desperat",
        "foragtelig",
        "NO TRANSLATION",
        "despotisk",
        "despoti",
        "nødlidende",
        "ødelagt",
        "destroyer",
        "ødelægge",
        "ødelæggelse",
        "Destruktiv",
        "løsgørelse",
        "tilbageholde",
        "anholdte",
        "tilbageholdelse",
        "forringes",
        "forværret",
        "forringelse",
        "afskyr",
        "detonere",
        "aflede opmærksomheden",
        "skade",
        "skadelig",
        "efterladenskaber",
        "ødelægge",
        "ødelæggende",
        "ødelæggelser",
        "djævel",
        "djævelsk",
        "lusket",
        "decentralisering",
        "Fortære",
        "djævelsk",
        "diagnose",
        "diatribe",
        "diktator",
        "diktatorisk",
        "diktatur",
        "NO TRANSLATION",
        "vanskeligheder",
        "vanskelighed",
        "sidespring",
        "faldefærdige",
        "udvande",
        "formindske",
        "formindsket",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "smuds",
        "snavset",
        "handicap",
        "deaktivere",
        "handicappet",
        "utilfredse",
        "være uenig",
        "uenige",
        "uenighed",
        "ikke tilladt",
        "skuffe",
        "skuffet",
        "skuffende",
        "skuffelse",
        "misbilligelse",
        "misbillige",
        "afvist",
        "misbilligende",
        "katastrofe",
        "katastrofal",
        "tvivle",
        "udsmid",
        "udledning",
        "disciplin",
        "fralægger",
        "misfarvning",
        "misfarvet",
        "ubehag",
        "koble fra",
        "afbrudt",
        "frakobling",
        "utilfredshed",
        "afbryde",
        "diskontinuitet",
        "disharmoni",
        "afskrække",
        "modløshed",
        "miskreditere",
        "diskriminere",
        "diskriminerende",
        "forskelsbehandling",
        "Foragt",
        "sygdom",
        "syge",
        "ulegemlig",
        "udkobling",
        "vansiret",
        "vanære",
        "NO TRANSLATION",
        "vanærende",
        "utilfredse",
        "afsky",
        "ulækkert",
        "modløs",
        "nedslående",
        "uærlig",
        "uærlighed",
        "vanære",
        "desillusionering",
        "misinformation",
        "tilsnigelse",
        "smuldre",
        "disintegration",
        "uinteresseret",
        "kan ikke lide",
        "hadede",
        "forvredet",
        "trist",
        "forfærdelse",
        "sønderlemmelse",
        "afskedigelse",
        "ulydighed",
        "ulydig",
        "være ulydig",
        "sygdom",
        "uordentligt",
        "uorganiseret",
        "underkende",
        "nedsættende",
        "ulighed",
        "lidenskabsløs",
        "fjerne",
        "spredning",
        "fordrive",
        "utilfreds",
        "mishag",
        "bortskaffelse",
        "fordrevne",
        "bestride",
        "diskvalifikation",
        "diskvalificeret",
        "diskvalificere",
        "foragt",
        "bort",
        "berygtet",
        "respektløshed",
        "respektløst",
        "forstyrrelser",
        "utilfredshed",
        "splid",
        "afvigende",
        "bjørnetjeneste",
        "dissident",
        "opløsning",
        "dissonans",
        "afsmag",
        "usmagelig",
        "forvrænget",
        "forvrængning",
        "distrahere",
        "distraheret",
        "distraherende",
        "distraktion",
        "fortvivlet",
        "nød",
        "nødstedte",
        "rystende",
        "mistillid",
        "forstyrrelse",
        "forstyrret",
        "ude af brug",
        "nedlagte",
        "divergerende",
        "frasolgte",
        "frasalg",
        "skilsmisse",
        "svimmelhed",
        "svimmel",
        "docket",
        "NO TRANSLATION",
        "dødvande",
        "dole",
        "NO TRANSLATION",
        "dominerende",
        "dominans",
        "æsel",
        "doodle",
        "doom",
        "dømt",
        "dommedag",
        "tvivl",
        "tvivlsom",
        "tvivlende",
        "douche",
        "dyster",
        "fald",
        "kedelig",
        "dræning",
        "ulempe",
        "rædsel",
        "forfærdelig",
        "frygtelig",
        "kedelig",
        "drikke",
        "vrøvl",
        "drone",
        "hængende",
        "tørke",
        "drukne",
        "døsighed",
        "slid",
        "beruset",
        "fuldskab",
        "tvivlsom",
        "kedelig",
        "dum",
        "dummy",
        "lossepladser",
        "dun",
        "fangehul",
        "dupe",
        "dobbelthed",
        "tvang",
        "støv",
        "væksthæmmede",
        "døende",
        "dysenteri",
        "jordskælv",
        "aflytning",
        "edikt",
        "feminin",
        "egoistisk",
        "ekstreme",
        "udstøde",
        "udstødning",
        "elimination",
        "undvigende",
        "afmagret",
        "NO TRANSLATION",
        "genere",
        "pinlig",
        "forlegenhed",
        "underslæb",
        "blodprop",
        "involveret",
        "nødsituation",
        "enklave",
        "indgreb",
        "behæftelse",
        "fare",
        "truede",
        "endemisk",
        "fjende",
        "håndhævelse",
        "gådefuld",
        "fjendskab",
        "slavebinde",
        "gjort til slaver",
        "slaveri",
        "viklet ind",
        "sammenfiltring",
        "indvolde",
        "misundelig",
        "epidemi",
        "epilepsi",
        "udrydde",
        "udryddelse",
        "slette",
        "erosion",
        "err",
        "vildfaren",
        "uregelmæssig",
        "Erratum",
        "fejlagtige",
        "fejl",
        "bryde ud",
        "udbrud",
        "eskalere",
        "tage afstand",
        "spionage",
        "fremmedgjort",
        "aktiv dødshjælp",
        "evakuere",
        "evakuering",
        "unddrage",
        "omgåelse",
        "forjage",
        "udsættelse",
        "ond",
        "forværre",
        "forværring",
        "krævende",
        "overdrive",
        "overdrevet",
        "undersøgelse",
        "harme",
        "udgravning",
        "overskydende",
        "punktafgifter",
        "udelukket",
        "Eksklusive",
        "undtagelse",
        "ekskrementer",
        "ulidelig",
        "undskyldning",
        "udførelse",
        "bøddel",
        "udstødning",
        "udmattet",
        "udmattelse",
        "NO TRANSLATION",
        "eksil",
        "eksorcisme",
        "udstationerede",
        "bortvise",
        "udgifter",
        "udgifter",
        "udløbe",
        "udløbet",
        "udråb",
        "eksplodere",
        "eksplosion",
        "eksplosiv",
        "udsat",
        "ekspropriation",
        "udvisning",
        "udrydde",
        "udryddelse",
        "uddød",
        "slukke",
        "udenretslige",
        "ekstremitet",
        "fabrikere",
        "fabrikation",
        "falme",
        "fæces",
        "svigtende",
        "fiasko",
        "besvimelse",
        "troløse",
        "falsk",
        "efterår",
        "fejlagtig",
        "fejlslutning",
        "fejlbarlig",
        "faldende",
        "brak",
        "falskhed",
        "falsk",
        "forfalskning",
        "forfalske",
        "falskheden",
        "vakle",
        "hungersnød",
        "fanatisk",
        "farce",
        "farceagtige",
        "fastende",
        "fed",
        "fatal",
        "dødsulykke",
        "skæbne",
        "træthed",
        "trættes",
        "fed",
        "fejl",
        "defekt",
        "fawn",
        "frygt",
        "frygtsomme",
        "frygtsomt",
        "frygtede",
        "febril",
        "fækal",
        "afføring",
        "betaling",
        "svag",
        "fintede",
        "faldt",
        "forbryder",
        "felony",
        "gære",
        "glubsk",
        "vildskab",
        "fejde",
        "feudale",
        "feudalisme",
        "febrilsk",
        "fiasko",
        "fib",
        "vægelsindet",
        "fiktiv",
        "djævel",
        "voldsom",
        "kæmpe",
        "kampene",
        "filibuster",
        "snavs",
        "beskidte",
        "skydevåben",
        "passer",
        "slasket",
        "slatten",
        "udflagning",
        "åbenlys",
        "flake",
        "klap",
        "flatulens",
        "flagre",
        "fejl",
        "loppe",
        "NO TRANSLATION",
        "fleece",
        "kødfulde",
        "vige",
        "piske",
        "flop",
        "rødspætte",
        "influenza",
        "fluktuation",
        "fjende",
        "forpurret",
        "dårskab",
        "narre",
        "tåbelig",
        "tåbelighed",
        "foder",
        "strejftog",
        "forbyde",
        "forbyder",
        "kraft",
        "tvunget",
        "med magt",
        "forudanelse",
        "afskærme",
        "afkald",
        "udenlandsk",
        "udlænding",
        "advaret",
        "miste",
        "fortabes",
        "fortabelse",
        "forfalskning",
        "glemme",
        "glemt",
        "forladt",
        "formløse",
        "utugt",
        "Svigte",
        "forladt",
        "modbydeligt",
        "knoglebrud",
        "skrøbelig",
        "skrøbelighed",
        "Hektisk",
        "svig",
        "svigagtig",
        "fyldt",
        "flosse",
        "flosset",
        "lunefulde",
        "fryser",
        "hektiske",
        "forrykte",
        "vanvid",
        "klynke",
        "forskrækkelse",
        "skræmme",
        "bange",
        "frygtelige",
        "frigid",
        "useriøst",
        "forfrysninger",
        "skum",
        "rynke panden",
        "vred",
        "frugtesløse",
        "frustrere",
        "frustreret",
        "frustration",
        "fusk",
        "flygtning",
        "fumle",
        "røg",
        "rygende",
        "svamp",
        "funk",
        "rasende",
        "furore",
        "raseri",
        "ballade",
        "kræsen",
        "forgæves",
        "tomhed",
        "gaby",
        "gag",
        "galde",
        "galger",
        "spille",
        "spiller",
        "gambling",
        "bande",
        "fængsel",
        "hul",
        "affald",
        "skrigende",
        "pynt",
        "flænge",
        "gispende",
        "NO TRANSLATION",
        "mager",
        "gent",
        "geriatriske",
        "skrækkelige",
        "ghetto",
        "spøgelsesagtige",
        "sludder",
        "iskold",
        "blænding",
        "grelt",
        "glib",
        "dysterhed",
        "dyster",
        "mut",
        "overflod",
        "frådseri",
        "gnome",
        "goblin",
        "gudløse",
        "gonoré",
        "goo",
        "Gore",
        "kløft",
        "gorilla",
        "bloddryppende",
        "sladre",
        "gouge",
        "gigt",
        "regering",
        "tag fat",
        "gribe",
        "rist",
        "revet",
        "rist",
        "grav",
        "grådighed",
        "grådig",
        "granat",
        "sorg",
        "klage",
        "sørge over",
        "grov",
        "barsk",
        "snavs",
        "snavset",
        "slibning",
        "uhyggelig",
        "grizzly",
        "stønne",
        "NO TRANSLATION",
        "brutto",
        "grotesk",
        "jordet",
        "grundløse",
        "knurre",
        "knurren",
        "nag",
        "modstræbende",
        "grusomme",
        "bister",
        "knurre",
        "gnaven",
        "guerilla",
        "list",
        "guillotinen",
        "skyld",
        "skyldig",
        "skikkelse",
        "måge",
        "godtroende",
        "kanon",
        "vælde",
        "Guzzling",
        "sigøjner",
        "hag",
        "udtæret",
        "behåret",
        "halvvejs",
        "hallucination",
        "grime",
        "standse",
        "hæmme",
        "forstrækning",
        "handikap",
        "hængende",
        "bøddel",
        "plage",
        "Harbinger",
        "hærdet",
        "hårdhed",
        "trængsler",
        "skøge",
        "skade",
        "skadelig",
        "rystende",
        "harry",
        "hårdhed",
        "hash",
        "hash",
        "forhastet",
        "had",
        "hadefulde",
        "hade",
        "had",
        "hovmodige",
        "hjemsøge",
        "hjemsøgt",
        "ødelæggelse",
        "fare",
        "farlig",
        "dis",
        "hovedpine",
        "berusende",
        "høring",
        "rygter",
        "rustvogn",
        "hjertesorg",
        "halsbrand",
        "hjerteløs",
        "hedning",
        "stærkt",
        "hæl",
        "øge",
        "afskyelig",
        "helvede",
        "helvedes",
        "hjælpeløs",
        "hjælpeløshed",
        "blødning",
        "hæmorider",
        "kætteri",
        "kætter",
        "hermafrodit",
        "heroin",
        "herpes",
        "herpesvirus",
        "tøven",
        "skjult",
        "hæslige",
        "hindre",
        "hindring",
        "hippie",
        "hvisle",
        "hvislende",
        "hit",
        "hidtil",
        "bistade",
        "hæs",
        "ældgamle",
        "fupnummer",
        "hobo",
        "hog",
        "hule",
        "holocaust",
        "hjemløs",
        "hjemve",
        "morderiske",
        "drab",
        "homoseksualitet",
        "hætte",
        "hooked",
        "tude",
        "håbløs",
        "håbløshed",
        "horde",
        "forfærdelig",
        "grueligt",
        "fælt",
        "rædselsvækkende",
        "forfærdet",
        "gruopvækkende",
        "rædsel",
        "rædsler",
        "gidsel",
        "fjendtlig",
        "fjendtligheder",
        "fjendtlighed",
        "hyle",
        "mopset",
        "humbug",
        "ydmyge",
        "ydmygende",
        "ydmygelse",
        "forudanelse",
        "sulten",
        "jæger",
        "jagt",
        "orkan",
        "skyndte sig",
        "gøre ondt",
        "sårende",
        "såre",
        "hustler",
        "hydra",
        "hydrocephalus",
        "hype",
        "overdrivelse",
        "hykleri",
        "hykler",
        "dobbeltmoralsk",
        "hysteri",
        "hysterisk",
        "idioti",
        "idiot",
        "idiotisk",
        "stjernehjul",
        "afgudsdyrkelse",
        "uvidenhed",
        "uvidende",
        "ignorere",
        "syg",
        "ulovlig",
        "ulovlighed",
        "ulæselig",
        "uægte",
        "ulovlig",
        "analfabetisk",
        "sygdom",
        "ulogisk",
        "illusion",
        "efterlignet",
        "efterligning",
        "umoden",
        "umodenhed",
        "umoralsk",
        "umoral",
        "hæmmet",
        "leverfunktion",
        "ufremkommelig",
        "utålmodighed",
        "utålmodig",
        "anklage",
        "rigsretssag",
        "hindre",
        "ufuldkommenhed",
        "ufuldkomment",
        "udgive",
        "personifikation",
        "uforsonlig",
        "implicere",
        "uhøfligt",
        "indførelse",
        "umulig",
        "impotens",
        "impotent",
        "impound",
        "uigennemførlig",
        "fængsle",
        "fængslet",
        "fængsling",
        "uregelmæssigheder",
        "uforsigtig",
        "uren",
        "urenhed",
        "imputering",
        "manglende evne",
        "utilgængelig",
        "forkert",
        "passivitet",
        "inaktivitet",
        "utilstrækkelighed",
        "utilstrækkelig",
        "afvises",
        "åndsforladt",
        "uanvendelig",
        "upassende",
        "uopmærksomhed",
        "uhørlig",
        "uoverskuelige",
        "uarbejdsdygtighed",
        "indespærring",
        "i tilfælde af",
        "brandbomber",
        "røgelse",
        "uophørlige",
        "blodskam",
        "incestuøs",
        "forbrænding",
        "tilskynde",
        "barskt",
        "usammenhængende",
        "uforenelig",
        "inkompetence",
        "inkompetent",
        "ufuldstændige",
        "uforståelig",
        "inkongruent",
        "ligegyldig",
        "ubetænksom",
        "uoverensstemmelse",
        "ubelejligt",
        "ukorrekt",
        "skeptisk",
        "strafbarhed",
        "Incubus",
        "pådrage sig",
        "uhelbredelig",
        "indtrængen",
        "uanstændig",
        "ubeslutsomhed",
        "ubeslutsom",
        "uforsvarligt",
        "friholde",
        "indenture",
        "ubestemt",
        "anklage",
        "anklage",
        "ligegyldighed",
        "trængende",
        "indignerede",
        "harme",
        "utydelig",
        "indoktrinering",
        "indolent",
        "ineffektiv",
        "virkningsløs",
        "ineffektivitet",
        "ineffektiv",
        "uduelig",
        "uduelighed",
        "ulighed",
        "uretfærdig",
        "indifferent",
        "utilgiveligt",
        "NO TRANSLATION",
        "uerfarne",
        "uforklarlig",
        "berygtede",
        "skændsel",
        "barnemord",
        "infantil",
        "infarkt",
        "inficere",
        "infektion",
        "smitsom",
        "underlegen",
        "underlegenhed",
        "helvede",
        "barnløshed",
        "skadedyrsangreb",
        "vantro",
        "utroskab",
        "svagelige",
        "svagelighed",
        "betændelse",
        "oppustet",
        "inflation",
        "påføre",
        "Udsættelse",
        "influenza",
        "informant",
        "overtrædelse",
        "sjældent",
        "krænkelse",
        "inhibere",
        "ugæstfri",
        "umenneskelig",
        "umenneskelighed",
        "fjendtlig",
        "Uret",
        "påbud",
        "beskadige",
        "tilskadekomne",
        "skadelig",
        "skade",
        "uretfærdighed",
        "indsatte",
        "inoperativ",
        "sindssyg",
        "sindssyge",
        "usikker",
        "usikkerhed",
        "snigende",
        "ubetydelighed",
        "ubetydelig",
        "fadt",
        "uforskammet",
        "insolvens",
        "konkurs",
        "ustabilitet",
        "anstifte",
        "anstiftelse",
        "insufficiens",
        "utilstrækkelig",
        "utilstrækkeligt",
        "fornærme",
        "fornærmende",
        "oprørernes",
        "uovervindelige",
        "oprør",
        "inter",
        "forbud",
        "interferens",
        "begravelse",
        "afbryde",
        "afbrudt",
        "testamente",
        "skræmme",
        "intimidering",
        "utålelig",
        "intolerance",
        "intolerant",
        "beruset",
        "umedgørlig",
        "intrige",
        "ubuden gæst",
        "indbrud",
        "påtrængende",
        "invadere",
        "angriber",
        "afkræfte",
        "ugyldiggørelse",
        "invaliditet",
        "invasion",
        "ufrivillig",
        "involution",
        "harmdirrende",
        "NO TRANSLATION",
        "strygejern",
        "irrationel",
        "irrationalitet",
        "uforenelige",
        "uregelmæssig",
        "uregelmæssighed",
        "irrelevant",
        "uoprettelig",
        "uansvarlig",
        "respektløs",
        "uigenkaldelig",
        "irritabilitet",
        "irritabel",
        "irriterende",
        "irritation",
        "isolerede",
        "isolation",
        "jabber",
        "fængsel",
        "jargon",
        "disharmonisk",
        "gulsot",
        "jaloux",
        "misundelse",
        "True",
        "fare",
        "John",
        "joke",
        "NO TRANSLATION",
        "virvar",
        "junk",
        "junta",
        "ungdoms",
        "kern",
        "sparke",
        "kidnappe",
        "dræbe",
        "drab",
        "glente",
        "stemt ned",
        "knyttede",
        "arbejdede",
        "besværlig",
        "labyrint",
        "mangel",
        "mangler",
        "glansløse",
        "lastet",
        "forsinkelse",
        "halter",
        "hule",
        "klagesang",
        "jordskred",
        "sløv",
        "sygne hen",
        "smægtende",
        "bortfalder",
        "tyveri",
        "øjenvippe",
        "sent",
        "sene",
        "latent",
        "latriner",
        "latterlig",
        "lava",
        "lovløshed",
        "retssag",
        "jurist",
        "slap",
        "afføringsmiddel",
        "doven",
        "lække",
        "lækage",
        "utæt",
        "forlade",
        "igle",
        "igler",
        "NO TRANSLATION",
        "citron",
        "spedalskhed",
        "lesbisk",
        "mindske",
        "mindre",
        "dødbringende",
        "sløvhed",
        "leukæmi",
        "afgift",
        "uanstændig",
        "forbindelsesofficer",
        "løgner",
        "bagvaskelse",
        "slikke",
        "ligge",
        "livløs",
        "begrænset",
        "halte",
        "fnug",
        "spiritus",
        "sløv",
        "procespart",
        "føre proces",
        "retssager",
        "litigious",
        "kuld",
        "gusten",
        "brød",
        "dagdriver",
        "NO TRANSLATION",
        "væmmes",
        "afsky",
        "modbydelig",
        "lobbyist",
        "NO TRANSLATION",
        "johannesbrødkernemel",
        "ophøjede",
        "ensomhed",
        "ensom",
        "ensom",
        "loo",
        "væv",
        "Loon",
        "loony",
        "plyndre",
        "tabe",
        "miste",
        "tab",
        "faret vild",
        "loudness",
        "stue",
        "lus",
        "nederste",
        "sænkning",
        "laveste",
        "lavlandet",
        "ydmyg",
        "latterlig",
        "klodsede",
        "klump",
        "klumpet",
        "vanvid",
        "sindssyg",
        "stikken",
        "lokke",
        "skumle",
        "lure",
        "lurer",
        "frodig",
        "begær",
        "lystne",
        "at lyve",
        "Lynch",
        "muskatblomme",
        "gal",
        "Madden",
        "galning",
        "vanvid",
        "mafia",
        "maddike",
        "improviseret",
        "sygdom",
        "utilpashed",
        "malaria",
        "ondsindet",
        "embedsmisbrug",
        "misdannelse",
        "ondskab",
        "ondsindet",
        "malign",
        "malignitet",
        "ondartet",
        "fejlbehandling",
        "mandamus",
        "NO TRANSLATION",
        "mangle",
        "mani",
        "sindsyg",
        "maniske",
        "manipulere",
        "manipulation",
        "manddrab",
        "gødning",
        "Mar",
        "margen",
        "maroon",
        "martingale",
        "martyr",
        "martyrium",
        "masochisme",
        "massakre",
        "materialisme",
        "materialistiske",
        "bugtet",
        "meningsløs",
        "mæslinger",
        "blande sig",
        "middelmådig",
        "middelmådighed",
        "melankolsk",
        "melankoli",
        "nærkamp",
        "melodrama",
        "nedsmeltning",
        "trussel",
        "truende",
        "underordnede",
        "lejesoldat",
        "nådesløs",
        "rod",
        "rodet",
        "metastaser",
        "methanol",
        "meldug",
        "milits",
        "mimicry",
        "minimere",
        "minimum",
        "mindretal",
        "NO TRANSLATION",
        "dårlig opførsel",
        "abort",
        "ballade",
        "drilagtig",
        "misforståelse",
        "dårlig opførsel",
        "elendig",
        "ynkeligt",
        "elendighed",
        "ulykke",
        "vildledt",
        "uheld",
        "fejlfortolkning",
        "vildlede",
        "misvisende",
        "dårlig ledelse",
        "misforhold",
        "misvisende",
        "forlægge",
        "malplaceret",
        "forvanske",
        "vildledning",
        "Misrepresented",
        "mangler",
        "fejlinformation",
        "fejl",
        "fejl",
        "elskerinde",
        "NO TRANSLATION",
        "misforstå",
        "misforståelse",
        "misbruge",
        "mide",
        "mob",
        "hån",
        "spottende",
        "forulempelse",
        "monokrom",
        "monopolist",
        "Monsun",
        "uhyre",
        "skrummel",
        "humørsyg",
        "omstridt",
        "morbid",
        "sygelighed",
        "lighus",
        "døende",
        "fjols",
        "moronic",
        "bid",
        "dødelig",
        "dødelighed",
        "selvfornægtelse",
        "lighus",
        "myg",
        "sørge over",
        "vemodigt",
        "sorg",
        "møg",
        "mudder",
        "roderi",
        "rodede",
        "mudret",
        "muffe",
        "muldyr",
        "mor",
        "mumle",
        "fåresyge",
        "mord",
        "morder",
        "morderiske",
        "skumle",
        "NO TRANSLATION",
        "muggen",
        "mutant",
        "lemlæstet",
        "lemlæstelse",
        "mytteri",
        "NO TRANSLATION",
        "snude",
        "nærsynethed",
        "nab",
        "lavpunkt",
        "NO TRANSLATION",
        "naiv",
        "navnløs",
        "ble",
        "narkotisk",
        "grim",
        "uartig",
        "kvalme",
        "kvalme",
        "NO TRANSLATION",
        "Fornødne",
        "trængende",
        "forbryderiske",
        "negation",
        "negativ",
        "forsømme",
        "forsømt",
        "forsømme",
        "uagtsomhed",
        "uagtsom",
        "NO TRANSLATION",
        "neger",
        "nepotisme",
        "nervøs",
        "Neder",
        "brændenælde",
        "neuralgi",
        "neurose",
        "neurotisk",
        "nikotin",
        "nigger",
        "mareridt",
        "nihilisme",
        "støj",
        "støjende",
        "NO TRANSLATION",
        "nonsens",
        "meningsløse",
        "løkke",
        "intetheden",
        "skadelige",
        "plage",
        "NO TRANSLATION",
        "ophæve",
        "følelsesløs",
        "følelsesløshed",
        "NO TRANSLATION",
        "OAF",
        "overvægtige",
        "fedme",
        "obi",
        "obit",
        "nekrolog",
        "indvending",
        "anstødeligt",
        "forpligte",
        "låntageren",
        "udslette",
        "udslettet",
        "udslettelse",
        "glemsel",
        "klamt",
        "obskøn",
        "obskønitet",
        "ubemærkethed",
        "hindring",
        "stædig",
        "hindre",
        "obstruktion",
        "obstruktiv",
        "stump",
        "okkulte",
        "særhed",
        "frastødende",
        "lugt",
        "fornærme",
        "fornærmet",
        "gerningsmand",
        "forbrydelse",
        "offensiv",
        "affejende",
        "opsejling",
        "trold",
        "olfaktoriske",
        "oligarki",
        "varsel",
        "ildevarslende",
        "udelade",
        "besværlig",
        "byrden",
        "sive",
        "uigennemsigtig",
        "opera",
        "opiat",
        "påståelig",
        "opium",
        "modstander",
        "modsætte sig",
        "imod",
        "modstand",
        "undertrykke",
        "undertrykkelse",
        "undertrykkende",
        "undertrykkeren",
        "orc",
        "prøvelser",
        "ammunition",
        "sjældne",
        "angiveligt",
        "fortrænge",
        "udstødt",
        "ramaskrig",
        "udhus",
        "aparte",
        "fredløs",
        "skandale",
        "ovation",
        "anmassende",
        "overbelaste",
        "overskyet",
        "overdrive",
        "overdosis",
        "forsinket",
        "overvurderet",
        "flyde over",
        "tilgroet",
        "overbelaste",
        "overbetalte",
        "overmande",
        "overvældende",
        "overpris",
        "tilsyn",
        "styrte",
        "vælte",
        "overvælde",
        "overvældet",
        "På grund",
        "oxidation",
        "smerte",
        "forpint",
        "smertefuld",
        "smerteligt",
        "smerter",
        "parese",
        "pandemi",
        "NO TRANSLATION",
        "panik",
        "lammelse",
        "lammet",
        "paranoia",
        "parasit",
        "NO TRANSLATION",
        "papegøje",
        "påholdende",
        "partisan",
        "NO TRANSLATION",
        "passiv",
        "passivitet",
        "lappe",
        "patetisk",
        "nedladende",
        "NO TRANSLATION",
        "knapheden",
        "fattiglem",
        "Bonde",
        "hævn",
        "betaling",
        "ejendommeligheder",
        "fodgænger",
        "straffelov",
        "straf",
        "trænge ind",
        "fængselsvæsen",
        "fortabelse",
        "peril",
        "farefulde",
        "Forsvinde",
        "letfordærvelige",
        "omkom",
        "omkom",
        "mened",
        "perniciøs",
        "gerningsmand",
        "fortsættelse",
        "forvirret",
        "rådvildhed",
        "forfølge",
        "forfølgelse",
        "forstyrrelse",
        "kighoste",
        "pervers",
        "perversion",
        "pervers",
        "perverteret",
        "pessimisme",
        "pessimist",
        "skadedyr",
        "pest",
        "kæledyr",
        "smålige",
        "fantom",
        "slim",
        "falsk",
        "blokadevagt",
        "blokade",
        "lage",
        "svin",
        "Due",
        "bunker",
        "plyndring",
        "alfons",
        "filipens",
        "fyrretræ",
        "bagbinde",
        "pique",
        "piratkopiering",
        "pirat",
        "pistol",
        "faldgrube",
        "plagiat",
        "pest",
        "sagsøger",
        "forgyldt",
        "spiller",
        "anbringende",
        "skæbne",
        "møjsommelige",
        "styrtdykke",
        "plyndre",
        "springet",
        "lungebetændelse",
        "krybskytteri",
        "meningsløs",
        "gift",
        "forgiftet",
        "forgiftning",
        "giftig",
        "prikke",
        "polemisk",
        "polio",
        "forurene",
        "forurening",
        "polygami",
        "pomp",
        "pompøse",
        "tung",
        "dårligt",
        "pop",
        "hulepindsvin",
        "porno",
        "porno",
        "pornografisk",
        "pornografi",
        "positur",
        "besad",
        "besiddelse",
        "posthume",
        "udsættelse",
        "pund",
        "fattigdom",
        "magtesløs",
        "prank",
        "usikre",
        "distrikt",
        "aggressiv",
        "knibe",
        "graviditet",
        "fordomme",
        "forudindtaget",
        "skade",
        "overlagt",
        "tryk",
        "anmassende",
        "lade som om",
        "foregav",
        "foregiver",
        "forstillelse",
        "prætentioner",
        "forebyggende",
        "bytte",
        "pik",
        "stikkende",
        "fængsel",
        "fange",
        "lokum",
        "problem",
        "trække tiden ud",
        "Overspringshandling",
        "blasfemisk",
        "bandeord",
        "overflod",
        "forbudt",
        "forbud",
        "forlænge",
        "løs på tråden",
        "propaganda",
        "rejse tiltale",
        "retsforfølgelse",
        "prostitueret",
        "prostitution",
        "provokation",
        "provokerende",
        "lirke",
        "nysgerrige",
        "psykose",
        "publicist",
        "puffy",
        "patrice",
        "bidende",
        "straffe",
        "straffet",
        "straffe",
        "straf",
        "straffende",
        "skærsilden",
        "purge",
        "pus",
        "kvaksalver",
        "hængedynd",
        "vagtler",
        "dilemma",
        "skændes",
        "omstøde",
        "undertrykke",
        "tvivlsom",
        "quicksilver",
        "Afslut",
        "pilekogger",
        "dirrende",
        "quiz",
        "rak",
        "rabiat",
        "rabies",
        "rack",
        "ketcher",
        "stråling",
        "radioaktiv",
        "radon",
        "raseri",
        "raser",
        "klude",
        "raid",
        "jernbane",
        "vædder",
        "vidtløftig",
        "krigsstien",
        "harsk",
        "løsepenge",
        "voldtage",
        "rovfugle",
        "slyngel",
        "udslæt",
        "rotte",
        "bedømmelse",
        "hæs",
        "glubende",
        "rablende",
        "reaktionær",
        "bag-",
        "Rebel",
        "irettesættelse",
        "afkræfte",
        "genstridige",
        "recession",
        "tilbagefald",
        "hensynsløs",
        "hensynsløshed",
        "overflødig",
        "reflux",
        "refraktær",
        "afslag",
        "nægte",
        "nægtede",
        "relatere",
        "regression",
        "fortryde",
        "beklageligt",
        "fortrudt",
        "beklager",
        "lovgivningsmæssige",
        "rein",
        "afvise",
        "afvist",
        "afvisning",
        "afviser",
        "tilbagefald",
        "nedrykning",
        "opgive",
        "modstræbende",
        "varetægtsfængslede",
        "afhjælpende",
        "efterladende",
        "anger",
        "fjernelse",
        "fjerne",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "frafalden",
        "give afkald på",
        "afkald",
        "NO TRANSLATION",
        "frastødende",
        "frastødende",
        "undertrykke",
        "undertrykkelse",
        "irettesættelse",
        "genoptryk",
        "repressalier",
        "bebrejdelse",
        "republik",
        "afvisning",
        "frastødning",
        "ophæve",
        "ophævelse",
        "harmes over",
        "krænket",
        "vrede",
        "træde tilbage",
        "resignation",
        "resigneret",
        "modstå",
        "modstand",
        "resistente",
        "modstå",
        "begrænse",
        "begrænse",
        "begrænsning",
        "restriktiv",
        "gøre gengæld",
        "repressalier",
        "gengældelsesaktioner",
        "retard",
        "retardering",
        "tilbageholdende",
        "retort",
        "trække tilbage",
        "tilbagetrækning",
        "nedskæringer",
        "gengældelse",
        "retrograd",
        "hævn",
        "vending",
        "tilbagekaldelse",
        "tilbagekalde",
        "opstand",
        "oprørende",
        "revolver",
        "afsky",
        "gigt",
        "vakkelvorne",
        "gennemhullet",
        "latterliggøre",
        "latterlig",
        "udbredt",
        "riffel",
        "splittelse",
        "stiv",
        "stivhed",
        "stringens",
        "stringent",
        "ringetone",
        "optøjer",
        "riotous",
        "risiko",
        "risikabel",
        "rivalisering",
        "røve",
        "røver",
        "røveri",
        "Rogue",
        "råge",
        "rådne",
        "rådner op",
        "ruhed",
        "NO TRANSLATION",
        "række",
        "larmende",
        "vrøvl",
        "murbrokker",
        "rue",
        "flæse",
        "robust",
        "ruin",
        "ødelagt",
        "ruinerende",
        "rygte",
        "løb væk",
        "brud",
        "NO TRANSLATION",
        "rust",
        "rusten",
        "ubarmhjertig",
        "NO TRANSLATION",
        "sabotage",
        "ofre",
        "desværre",
        "sorg",
        "synke",
        "saft",
        "sarkasme",
        "sarkom",
        "sardonic",
        "sataniske",
        "mættet",
        "brutal",
        "vildskab",
        "skurv",
        "stillads",
        "skalpel",
        "skællende",
        "skandale",
        "skandaløs",
        "sparsom",
        "syndebuk",
        "ar",
        "knap",
        "næppe",
        "mangel",
        "skræmme",
        "scavenger",
        "ordning",
        "skisma",
        "skizofreni",
        "iskias",
        "håner",
        "skælde ud",
        "skæld ud",
        "glohed",
        "hån",
        "skorpion",
        "skotsk whisky",
        "slyngel",
        "svøbe",
        "scrambling",
        "scrapie",
        "skrige",
        "skrigende",
        "skrig",
        "skruet",
        "scrimmage",
        "skrubbe",
        "granske",
        "kontrol",
        "udskud",
        "ætse",
        "løsrivelse",
        "afsondret",
        "NO TRANSLATION",
        "sekretion",
        "hemmelighedsfuld",
        "sekterisk",
        "oprør",
        "forføre",
        "forførelse",
        "udskille",
        "segregeret",
        "gribe",
        "selvisk",
        "selvoptagethed",
        "senil",
        "meningsløs",
        "dømme",
        "separatistiske",
        "sepsis",
        "septisk",
        "beslaglæggelse",
        "fredfyldte",
        "slange",
        "tjener",
        "tjene",
        "servil",
        "trældom",
        "tilbageslag",
        "skille",
        "spildevand",
        "kloakering",
        "lurvet",
        "skur",
        "bøjle",
        "lyssky",
        "ryster",
        "rystende",
        "falsk",
        "rodebutik",
        "skam",
        "skammeligt",
        "skamløs",
        "shanghai",
        "haj",
        "splintre",
        "knust",
        "skur",
        "skal",
        "skrinlagt",
        "skibbrud",
        "lort",
        "gyse",
        "chok",
        "sjuskede",
        "skyde",
        "skydning",
        "butikstyveri",
        "mangel",
        "mangel",
        "skud",
        "puffe",
        "prangende",
        "hyl",
        "skingrende",
        "krympe",
        "skrumpet",
        "gyse",
        "skye",
        "syg",
        "kvalmende",
        "sygelig",
        "sygdom",
        "fjollet",
        "NO TRANSLATION",
        "syndig",
        "skummel",
        "synder",
        "synde",
        "sirene",
        "tøsedreng",
        "skeptisk",
        "sketchy",
        "skæv",
        "udskridning",
        "springe",
        "træfning",
        "slæk",
        "slagge",
        "slam",
        "bagvaskelse",
        "bagtalende",
        "smække",
        "slagte",
        "slagteri",
        "slagtning",
        "slave",
        "slaveri",
        "dræbe",
        "slayer",
        "slud",
        "slimet",
        "slink",
        "glide",
        "NO TRANSLATION",
        "sløset",
        "dovendyr",
        "daske",
        "dødt væv",
        "langsommelighed",
        "slam",
        "slug",
        "træg",
        "slumkvarter",
        "nedturen",
        "nedværdigelse",
        "snesjap",
        "tøs",
        "snu",
        "lussing",
        "lille",
        "smadre",
        "smadret",
        "flyforsinkelser",
        "lugt",
        "lugte",
        "smørret grin",
        "slå",
        "ryger",
        "kvæle",
        "plamage",
        "selvglad",
        "smugle",
        "smugler",
        "smugling",
        "sjofelheder",
        "hage",
        "ulemper",
        "slange",
        "snare",
        "snerren",
        "snerrende",
        "snige sig",
        "snigende",
        "vrængen",
        "nyse",
        "spydig",
        "snob",
        "suge",
        "NO TRANSLATION",
        "socialist",
        "jord",
        "tilsmudset",
        "somatiske",
        "dyster",
        "sod",
        "trolddom",
        "beskidt",
        "øm",
        "hårdt",
        "ømhed",
        "sorg",
        "sorgfuld",
        "NO TRANSLATION",
        "sjælløs",
        "soulmate",
        "sur",
        "Spank",
        "spasmer",
        "spyttede",
        "spyd",
        "plet",
        "spøgelse",
        "spektral",
        "spekulation",
        "brugt",
        "gammeljomfru",
        "trods",
        "ondsindet",
        "splint",
        "dele",
        "opsplitning",
        "forkæle",
        "spoiler",
        "talte",
        "svamp",
        "skræmme",
        "forstuvning",
        "spree",
        "sprite",
        "uægte",
        "byge",
        "BZ'er",
        "sarte",
        "squelch",
        "vride",
        "dolke",
        "svimlende",
        "stillestående",
        "plet",
        "forslidt",
        "stilk",
        "standoff",
        "stilstand",
        "stirre",
        "skarp",
        "forskrække",
        "sult",
        "udsultet",
        "sultende",
        "stationær",
        "stav",
        "stjæle",
        "stjæle",
        "snigende",
        "stereotype",
        "stereotype",
        "steril",
        "sterilitet",
        "agterstavn",
        "stiv",
        "stivhed",
        "kvæle",
        "kvalt",
        "stigmatisering",
        "dødfødt",
        "stik",
        "stikkende",
        "nærig",
        "stinke",
        "stinkende",
        "tørn",
        "lagre",
        "stjålet",
        "sten-",
        "stenet",
        "afføring",
        "standsning",
        "storm",
        "stormfuld",
        "anstrengt",
        "stræder",
        "strandede",
        "fremmed",
        "kvæle",
        "omstrejfende",
        "stress",
        "strid",
        "strejke",
        "strimmel",
        "stribe",
        "strippet",
        "slag",
        "kamp",
        "spankulere",
        "snerpet",
        "snuble",
        "bedøvet",
        "forkrøblet",
        "Dum",
        "dumhed",
        "stupor",
        "stald",
        "kue",
        "emne",
        "underkastet",
        "underkastelse",
        "undertvingelse",
        "underordnet",
        "stævning",
        "nedsynkning",
        "tilskud",
        "overleve",
        "trække fra",
        "subversion",
        "undergravende",
        "undergrave",
        "bukke under",
        "suge",
        "sugekop",
        "sagsøge",
        "lide",
        "patient",
        "lidelse",
        "kvælende",
        "kvælning",
        "selvmordstanker",
        "selvmord",
        "tvær",
        "stævning",
        "sunket",
        "overfladisk",
        "overflødig",
        "overtroisk",
        "undertrykke",
        "undertrykkelse",
        "ekstragebyr",
        "surly",
        "overgivelse",
        "overgivelse",
        "modtagelig",
        "formode",
        "affjedring",
        "mistanke",
        "mistænksom",
        "vatpind",
        "sump",
        "sumpet",
        "hagekors",
        "hævelse",
        "slurk",
        "svin",
        "opsvulmet",
        "symptom",
        "synkope",
        "tabu",
        "afsmag",
        "NO TRANSLATION",
        "sammenfiltrede",
        "langsommelighed",
        "træg",
        "tarif",
        "plette",
        "bie",
        "smagløs",
        "håne",
        "skat",
        "drille",
        "drilleri",
        "kedelig",
        "NO TRANSLATION",
        "storm",
        "fristelse",
        "bebyggelsen",
        "terminal",
        "afslutning",
        "termit",
        "forfærdeligt",
        "terror",
        "terrorisme",
        "terrorist",
        "terrorisere",
        "stivkrampe",
        "tøjr",
        "tyveri",
        "teisme",
        "teokratisk",
        "tyv",
        "tørstig",
        "torn",
        "tornede",
        "tankeløs",
        "thrash",
        "trussel",
        "True",
        "truende",
        "tærske",
        "banke",
        "gashåndtag",
        "bandit",
        "dunk",
        "tordnende",
        "forpurre",
        "tiff",
        "sky",
        "frygtsomhed",
        "småfuld",
        "ordflom",
        "træt",
        "træthed",
        "trættende",
        "tit",
        "tudse",
        "tobak",
        "toilet",
        "slider",
        "tolerere",
        "tandpine",
        "pine",
        "revet i stykker",
        "torpedo",
        "glødende",
        "erstatningsret",
        "skadevoldende",
        "tortur",
        "rørt",
        "nærtagende",
        "sej",
        "toksisk",
        "toksin",
        "tragedie",
        "tragisk",
        "forræder",
        "tramp",
        "trance",
        "overtrædelse",
        "staffage",
        "fælder",
        "affald",
        "trashy",
        "traumatisk",
        "NO TRANSLATION",
        "parodi",
        "forræderiske",
        "forræderi",
        "forræderi",
        "rysten",
        "rysten",
        "bæven",
        "ulovlig indtrængen",
        "trængsel",
        "domstol",
        "trick",
        "svindel",
        "bagatel",
        "tripping",
        "trold",
        "generende",
        "trompet",
        "tumle",
        "svulst",
        "svulst",
        "tumult",
        "omtumlet",
        "turbulens",
        "turbulent",
        "oprør",
        "ryk",
        "tyfon",
        "tyranniske",
        "tyranni",
        "tyran",
        "grimhed",
        "grim",
        "mavesår",
        "skjulte",
        "ultimatum",
        "ude af stand",
        "uacceptabel",
        "uforklarlig",
        "ikke-godkendt",
        "løstliggende",
        "Uopnålig",
        "uinteressante",
        "uberettiget",
        "uundgåelig",
        "uvidende",
        "uudholdelig",
        "vantro",
        "utrolig",
        "ufødte",
        "uhyggelig",
        "ufølsom",
        "usikker",
        "uforanderlig",
        "urene",
        "ubehageligt",
        "samvittighedsløse",
        "bevidstløs",
        "forfatningsstridig",
        "ustyrlig",
        "ukontrolleret",
        "uafklaret",
        "undermineret",
        "underbetalt",
        "undermålere",
        "uønsket",
        "uønsket",
        "fortryde",
        "uro",
        "urolig",
        "uuddannet",
        "arbejdsløs",
        "ulige",
        "ujævn",
        "uforklarlig",
        "urimelig",
        "urimelighed",
        "utro",
        "ugunstige",
        "ufærdige",
        "nådesløs",
        "uheldig",
        "uvenlig",
        "uopfyldte",
        "umøbleret",
        "ugudelige",
        "utaknemmelig",
        "ulykkelighed",
        "ulykkelig",
        "usund",
        "uhellig",
        "uvæsentlig",
        "uimponeret",
        "uforbedrede",
        "uvidende",
        "uindviede",
        "uinspirerede",
        "uforståelig",
        "utilsigtet",
        "uinteresseret",
        "uinteressant",
        "uretfærdig",
        "uberettiget",
        "ubegrundet",
        "uvenlig",
        "ukendt",
        "ulovlig",
        "uden licens",
        "uheldig",
        "uoverskuelig",
        "unaturlig",
        "uofficiel",
        "ubetalt",
        "ubehagelig",
        "upopulær",
        "uforudsigelig",
        "uforberedt",
        "uproduktive",
        "urentable",
        "ubeskyttede",
        "upubliceret",
        "upålidelige",
        "ulykkelig",
        "uregerlig",
        "usikre",
        "utilfredsstillende",
        "utilfreds",
        "usmagelig",
        "skrupelløs",
        "uafviklede",
        "uskøn",
        "usofistikerede",
        "ubeskrivelige",
        "ustabil",
        "mislykket",
        "uegnet",
        "ubesungne",
        "ikke-understøttet",
        "uholdbar",
        "usympatisk",
        "utæmmet",
        "uholdbar",
        "utænkelig",
        "sjusket",
        "utidig",
        "untitled",
        "ufortalt",
        "genstridige",
        "utrænede",
        "usandt",
        "utroværdig",
        "uberettiget",
        "uvaskede",
        "uvelkomne",
        "utilpas",
        "uvilje",
        "uklogt",
        "uafvidende",
        "uværdig",
        "ubøjelige",
        "omvæltning",
        "opstand",
        "tumult",
        "ked",
        "urchin",
        "presserende",
        "ubrugelig",
        "tilrane",
        "tilranet",
        "åger",
        "ledig stilling",
        "intetsigende",
        "vag",
        "vage",
        "forgæves",
        "vampyr",
        "forsvundet",
        "forfængelighed",
        "varicella",
        "åreknuder",
        "vegetativ",
        "heftige",
        "hævn",
        "hævn",
        "hævngerrig",
        "venom",
        "giftig",
        "informationsmængde",
        "randen",
        "skadedyr",
        "imod",
        "svimmelhed",
        "veto",
        "vice",
        "ond",
        "offer",
        "offer",
        "skurk",
        "skurkagtige",
        "hævngerrig",
        "krænkelse",
        "vold",
        "voldsom",
        "voldsomt",
        "hugorm",
        "virulens",
        "virus",
        "visitation",
        "vixen",
        "volatilitet",
        "vulkan",
        "opkastning",
        "voodoo",
        "vulgær",
        "vulgaritet",
        "sårbarhed",
        "Grib",
        "vaffel",
        "jamre",
        "vente",
        "svælge",
        "NO TRANSLATION",
        "aftagende",
        "ønsker",
        "krig",
        "fængselsinspektør",
        "ware",
        "krigsførelse",
        "krigerisk",
        "advare",
        "warp",
        "skæv",
        "vorte",
        "spild",
        "spildt",
        "ødsel",
        "spilder",
        "rindende",
        "vakle",
        "svækket",
        "svagt",
        "svaghed",
        "have på",
        "træt",
        "træthed",
        "trætte",
        "ukrudt",
        "græde",
        "mærkelig",
        "weirdo",
        "NO TRANSLATION",
        "tøs",
        "whack",
        "indfald",
        "klynke",
        "pisk",
        "hvirvelvind",
        "whisky",
        "luder",
        "ond",
        "ondskab",
        "vild",
        "vild kat",
        "løbeild",
        "forsætlig",
        "skvat",
        "skvattet",
        "krympe",
        "heks",
        "hekseri",
        "trække",
        "visne",
        "visne",
        "ve",
        "kedelige",
        "sørgeligt",
        "ord",
        "orm",
        "slidt",
        "bekymret",
        "bekymre",
        "bekymrende",
        "værre",
        "forværring",
        "værdiløs",
        "sår",
        "tovtrækkeri",
        "vrede",
        "anrette",
        "vrag",
        "ødelagt",
        "skruenøgle",
        "brydning",
        "stakkel",
        "elendige",
        "forkert",
        "forseelser",
        "uretmæssig",
        "fejlagtigt",
        "smede",
        "skævt",
        "fremmedhad",
        "gabe",
        "gaben",
        "råbe",
        "gule farver",
        "vræl",
        "zip",
    ]
)

_ambivalent = set(
    [
        "overflod",
        "bevæbnet",
        "balsam",
        "prale",
        "larmende",
        "bogorm",
        "sorteper",
        "berømthed",
        "charmeret",
        "omgåelse",
        "meddelagtighed",
        "indrømme",
        "snedig",
        "afhængig",
        "alsidig",
        "dominere",
        "endeløs",
        "håndhæve",
        "erotisk",
        "flugt",
        "følelse",
        "flirt",
        "hagl",
        "hedonisme",
        "højeste",
        "ydmyg",
        "med det samme",
        "ubevægelig",
        "indkomst",
        "infiltration",
        "indflydelse",
        "intens",
        "uendelig",
        "intervention",
        "blonder",
        "liberal",
        "herre",
        "mødres",
        "jordemoder",
        "mor",
        "krus",
        "berygtet",
        "almagt",
        "udbrud",
        "fremragende",
        "parade",
        "omskrive",
        "petroleum",
        "Presentment",
        "fortabte",
        "citere",
        "rave",
        "regressiv",
        "genoplive",
        "resterne",
        "pensionering",
        "genoplive",
        "revolution",
        "fugleskræmsel",
        "afsondrethed",
        "sanselig",
        "forestilling",
        "rygrad",
        "pund",
        "saftige",
        "overtro",
        "overhøjhed",
        "omgive",
        "synonym",
        "forjættende",
        "teenagere",
        "behandle",
        "ubesejret",
        "utøjlede",
        "uventet",
        "utænkelig",
        "løsne",
        "op ad bakke",
        "stemme",
        "vægt",
        "længsel",
    ]
)
